* calculates "effect" statistics, e.g., post period average effect, etc.
* calculates ranks of these stats for treated states within events
* aggregates data and these ranks across events

local statlist postavg postelast msperatio preavg preelast premspe postmspe pre16elast pre16mspe
local aggstatlist mean median

* these variables uniquely identify observations in the file
* ${compresults}`procedure'`outcome'results${allopt}_`ttype'.dta
global idvars event statefipsnum group preconfig postconfig

* DEFINE THE MINIMUM WAGE TREATMENT INTENSITY
capture program drop createmwtreatment
program define createmwtreatment
egen maxmwtreatment = max(mwtreatment), by($idvars)
egen minmwtreatment = min(mwtreatment), by($idvars)
gen pctmwtreatment = maxmwtreatment/minmwtreatment - 1
end

* DEFINITION OF POSTAVG = raw effect, i.e., average of post-period differences
capture program drop postavgroutine
program define postavgroutine
keep if post == 1
egen postavg = mean(y_treated-y_synthetic), by($idvars)
egen tag = tag($idvars)
keep if tag == 1
end

* DEFINITION OF POSTELAST = post-period elasticity
capture program drop postelastroutine
program define postelastroutine

createmwtreatment
keep if post == 1
egen meandiff = mean(y_treated - y_synthetic), by($idvars)
egen meansynth = mean(y_synthetic), by($idvars)
gen postelast = (meandiff/meansynth)/pctmwtreatment
egen tag = tag($idvars)
keep if tag == 1
end

* DEFINITION OF MSPERATIO = post:pre mspe ratio
capture program drop msperatioroutine
program define msperatioroutine
egen _postavgdiff = mean((y_treated-y_synthetic)^2) if post == 1, by($idvars)
egen postavgdiff = max(_postavgdiff), by($idvars)
egen _preavgdiff = mean((y_treated-y_synthetic)^2) if post == 0, by($idvars)
egen preavgdiff = max(_preavgdiff), by($idvars)
gen msperatio = postavgdiff / preavgdiff
egen tag = tag($idvars)
keep if tag == 1
end

* DEFINITION OF PREAVG = pre-period raw effect, i.e., average of pre-period differences
capture program drop preavgroutine
program define preavgroutine
keep if post == 0
egen preavg = mean(y_treated-y_synthetic), by($idvars)
egen tag = tag($idvars)
keep if tag == 1
end

* DEFINITION OF PREELAST = pre-period elasticity
capture program drop preelastroutine
program define preelastroutine
createmwtreatment
keep if post == 0
egen meandiff = mean(y_treated - y_synthetic), by($idvars)
egen meansynth = mean(y_synthetic), by($idvars)
gen preelast = (meandiff/meansynth)/pctmwtreatment
egen tag = tag($idvars)
keep if tag == 1
end

* DEFINITION OF PRE16ELAST = pre-period elasticity for t > -16
capture program drop pre16elastroutine
program define pre16elastroutine
createmwtreatment
gen negpost = post
recode negpost (1 = 0) (0 = -1)
gen negdate = -date
gen time = .
bysort event statefipsnum (date): replace time = sum(post)
bysort event statefipsnum (negdate): replace time = sum(negpost) if post == 0
keep if time >= -16 & time <= -1
assert post == 0
egen meandiff = mean(y_treated - y_synthetic), by($idvars)
egen meansynth = mean(y_synthetic), by($idvars)
gen pre16elast = (meandiff/meansynth)/pctmwtreatment
egen tag = tag($idvars)
keep if tag == 1
end


* DEFINITION OF PREMSPE = pre mspe
capture program drop premsperoutine
program define premsperoutine
egen _premspe = mean((y_treated-y_synthetic)^2) if post == 0, by($idvars)
egen premspe = max(_premspe), by($idvars)
egen tag = tag($idvars)
keep if tag == 1
end

* DEFINITION OF PRE16MSPE = pre mspe for t > -16
capture program drop pre16msperoutine
program define pre16msperoutine
gen negpost = post
recode negpost (1 = 0) (0 = -1)
gen negdate = -date
gen time = .
bysort event statefipsnum (date): replace time = sum(post)
bysort event statefipsnum (negdate): replace time = sum(negpost) if post == 0
keep if time >= -16 & time <= -1
assert post == 0
egen _pre16mspe = mean((y_treated-y_synthetic)^2) if post == 0, by($idvars)
egen pre16mspe = max(_pre16mspe), by($idvars)
egen tag = tag($idvars)
keep if tag == 1
end

* DEFINITION OF POSTMSPE = post mspe
capture program drop postmsperoutine
program define postmsperoutine
egen _postmspe = mean((y_treated-y_synthetic)^2) if post == 1, by($idvars)
egen postmspe = max(_postmspe), by($idvars)
egen tag = tag($idvars)
keep if tag == 1
end



* do the statistic calculation and aggregation
foreach procedure in $procedurelist {
	foreach outcome in $outcomelist {

		foreach statistic in `statlist' {
			* by event: calculate statistics
			foreach ttype in actuals placebos {
				if $`ttype' == 1 {
					use ${compresults}`procedure'`outcome'results${allopt}_`ttype'.dta, clear
					if "`statistic'" ~= "premspe" {
						egen _premspe = mean((y_treated-y_synthetic)^2) if post == 0, by($idvars)
						egen premspe = max(_premspe), by($idvars)
					}
					`statistic'routine
					keep division event group *treatment placebo `statistic' region premspe stateabb statefipsnum treat* preconfig postconfig
					save ${aggresults}`procedure'`outcome'`statistic'${allopt}_`ttype'_byevent.dta, replace
				}
			}

			* aggregate: stats for actually treated
			if $actuals == 1 {
				foreach aggstat in `aggstatlist' {
					use ${aggresults}`procedure'`outcome'`statistic'${allopt}_actuals_byevent.dta, clear
					collapse (`aggstat') `statistic', by(group preconfig postconfig)
					rename `statistic' `statistic'`aggstat'
					save ${aggresults}`procedure'`outcome'`statistic'${allopt}_actuals_`aggstat'.dta, replace
				} // agstat	
			} // $actuals==1

			* create ranks and also aggregate ranks
			if $actuals == 1 & $placebos == 1 {
				* first create within-event ranks
				use ${aggresults}`procedure'`outcome'`statistic'${allopt}_placebos_byevent.dta, clear
				append using ${aggresults}`procedure'`outcome'`statistic'${allopt}_actuals_byevent.dta

				egen `statistic'rank = rank(`statistic'), by(event group preconfig postconfig)
				egen statecount = count(statefipsnum), by(event group preconfig postconfig)
				egen _donorcount = count(statefipsnum) if placebo == 1, by(event group preconfig postconfig)
				egen donorcount = max(_donorcount), by(event group preconfig postconfig)
				drop _donorcount
				* use Weibull rule for percentile ranks
				gen `statistic'prank = `statistic'rank / (statecount + 1)
				save ${aggresults}`procedure'`outcome'`statistic'${allopt}_ranked_byevent.dta, replace
		
				* now aggregate ranks for actual treatments
				foreach aggstat in `aggstatlist' {
					use ${aggresults}`procedure'`outcome'`statistic'${allopt}_ranked_byevent.dta, clear
					keep if treated == 1
					collapse (`aggstat') `statistic' `statistic'prank, by(group preconfig postconfig)
					rename `statistic' `statistic'`aggstat'
					rename `statistic'prank `statistic'prank`aggstat'
					save ${aggresults}`procedure'`outcome'`statistic'${allopt}_ranked_`aggstat'.dta, replace
				} // aggstat
			} // if $actuals == 1 & $placebos == 1
		} // statlist

		* grab actuals and/or placebos stats and make wide
		foreach ttype in actuals placebos {
			if $`ttype' == 1 {
				local counter = 0
				foreach statistic in `statlist' {
					local counter = `counter' + 1
					if `counter' == 1 use ${aggresults}`procedure'`outcome'`statistic'${allopt}_`ttype'_byevent.dta, clear
					merge 1:1 group preconfig postconfig event statefipsnum using ${aggresults}`procedure'`outcome'`statistic'${allopt}_`ttype'_byevent.dta, nogenerate assert(3) keepusing(`statistic')
					save ${aggresults}`procedure'`outcome'statistics${allopt}_`ttype'_byevent.dta, replace
					erase ${aggresults}`procedure'`outcome'`statistic'${allopt}_`ttype'_byevent.dta
				} // statistic
			} // if $ttype==1
		} // ttype

		* grab aggregated actuals and make wide
		if $actuals == 1 {
			local counter = 0
			foreach statistic in `statlist' {
				foreach aggstat in `aggstatlist' {
					local counter = `counter' + 1
					if `counter' == 1 use ${aggresults}`procedure'`outcome'`statistic'${allopt}_actuals_`aggstat'.dta, clear
					merge 1:1 group preconfig postconfig using ${aggresults}`procedure'`outcome'`statistic'${allopt}_actuals_`aggstat'.dta, nogenerate assert(3) keepusing(`statistic'*)
					save ${aggresults}`procedure'`outcome'statistics${allopt}_actuals_aggregated.dta, replace
					erase ${aggresults}`procedure'`outcome'`statistic'${allopt}_actuals_`aggstat'.dta
				} // aggstat
			} // statistic
		} // actuals

		* grab ranks and aggregated ranks and make wide
		* ranks within events
		if $actuals == 1 & $placebos == 1 {
			local counter = 0
			foreach statistic in `statlist' {
				local counter = `counter' + 1
				if `counter' == 1 use ${aggresults}`procedure'`outcome'`statistic'${allopt}_ranked_byevent.dta, clear
				merge 1:1 event group preconfig postconfig statefipsnum using ${aggresults}`procedure'`outcome'`statistic'${allopt}_ranked_byevent.dta, nogenerate assert(3) keepusing(`statistic'*)
				save ${aggresults}`procedure'`outcome'statistics${allopt}_ranked_byevent.dta, replace
				erase ${aggresults}`procedure'`outcome'`statistic'${allopt}_ranked_byevent.dta
			} // statistic

			* aggregated ranks
			local counter = 0
			foreach statistic in `statlist' {
				foreach aggstat in `aggstatlist' {
					local counter = `counter' + 1
					if `counter' == 1 use ${aggresults}`procedure'`outcome'`statistic'${allopt}_ranked_`aggstat'.dta, clear
					merge 1:1 group preconfig postconfig using ${aggresults}`procedure'`outcome'`statistic'${allopt}_ranked_`aggstat'.dta, nogenerate assert(3) keepusing(`statistic'*)
					save ${aggresults}`procedure'`outcome'statistics${allopt}_ranked_aggregated.dta, replace
					erase ${aggresults}`procedure'`outcome'`statistic'${allopt}_ranked_`aggstat'.dta
				} // aggstat
			} // statistic
		} // if $actuals == 1 & $placebos == 1

	} // outcome
} // procedure


