* Produce quarterly X state cells of
* overall unemployment rate, union membership rate (only defined certain years), industry shares, mean age, lths
* age group specific: white share, black share, female share
* age group specific: mean wage, epop
local beginyear = 1979
local endyear = 2009
local basicusevarlist state _year month age grdatn _educ sex mlr unmem race ind wgt marstat
local morgusevarlist year intmonth state class class94 uhourse earnhre earnwke I25* age sex earnwt paidhre union*


* program to keep variables if they exist
capture program drop keepifexist
program define keepifexist
syntax anything
local keeplist ""
foreach x in `anything' {
	capture unab y: `x'
	if _rc == 0 {
		foreach z of varlist `y' {
			local keeplist `keeplist' `z'
		}
	}
	else local keeplist `keeplist'
}

if "`keeplist'" == "" noi di "Warning: none of those variables existed. All variables dropped."
else {
	di "Keeping `keeplist'"
	keep `keeplist'
}
end


* Load Unicon CPS Basic Data
forvalues year = `beginyear'/`endyear' {
	copy "${basicdata}unicon_cpsbasic_`year'.zip" ${rawdata}unicon_cpsbasic_`year'.zip, replace
	cd ${rawdata}
	unzipfile unicon_cpsbasic_`year', replace
	use "${rawdata}unicon_cpsbasic_`year'.dta", clear
	erase ${rawdata}unicon_cpsbasic_`year'.dta
	erase ${rawdata}unicon_cpsbasic_`year'.zip
	keepifexist `basicusevarlist'
	tempfile year`year'
	save `year`year''
}
cd ${do}
forvalues year = `beginyear'/`endyear' {
	if `year' == `beginyear' use `year`year'', clear
	else append using `year`year''
}

* there are three obs with missing state values
drop if state == -1
* there is one obs with a census state code of 3 (no state matches this)
drop if state == 3

* LIMIT SAMPLE TO 16+
keep if age >= 16 & age ~= .

* TIME
rename _year year

* MARITAL STATUS
gen byte married = .
replace married = 1 if marstat >= 1 & marstat <= 3
replace married = 0 if marstat >= 4 & marstat <= 7
drop marstat

* EDUCATION
* define college variable for ages 25+
gen byte college = .
replace college = 0 if year >= 1992 & grdatn > 0 & grdatn < 43
replace college = 1 if year >= 1992 & grdatn >= 43 & grdatn ~= .
replace college = 0 if year < 1992 & _educ > 0 & _educ < 16
replace college = 1 if year < 1992 & _educ >= 16 & _educ ~= .
drop _educ grdatn

* SEX
gen byte female = sex == 2 if sex ~= .
drop sex

* RACE
recode race (min/-1 = .)
gen byte white = race == 1 if race ~= .
gen byte black = race == 2 | race == 6 | (race >= 10 & race >= 12) | race == 15 | race == 16 | race == 19 if race ~= .
drop race

* LABOR FORCE
gen byte emp = .
replace emp = 1 if mlr >= 1 & mlr <= 2
replace emp = 0 if mlr >= 3 & mlr <= 7
replace emp = . if age <= 15

gen byte unemp = .
replace unemp = 0 if mlr >= 1 & mlr <= 2
replace unemp = 1 if mlr >= 3 & mlr <= 4
replace unemp = . if mlr == 4 & year >= 1976 & year <= 1998
replace unemp = . if age <= 15

drop mlr

* UNION
recode unmem (-1 = .) (2 = 0)

* WEIGHT
replace wgt = wgt / 100 if year >= 1976 & year <= 1993
replace wgt = wgt / 10000 if year >= 1994

* INDUSTRY
* Create aggregate industries using 1970,1980,1990,2002 Census codes
recode ind (-1 = .)
gen ind1970 = .
replace ind1970 = ind if year >= 1976 & year <= 1982
gen ind1980 = .
replace ind1980 = ind if year >= 1983 & year <= 1991
gen ind1990 = .
replace ind1990 = ind if year >= 1992 & year <= 2002
gen ind2002 = .
replace ind2002 = ind if year >= 2003
gen byte industry_1d = .
compress

* 1970 Census codes
* Ag & Mining
replace industry_1d = 1 if ind1970 >= 17 & ind1970 <= 58
* Construction
replace industry_1d = 2 if ind1970 >= 67 & ind1970 <= 78 
* Manufacturing
replace industry_1d = 3 if ind1970 >= 107 & ind1970 <= 399
* Transportation & Utilities & Communication
replace industry_1d = 4 if ind1970 >= 407 & ind1970 <= 499 
* Wholesale & Retail Trade
replace industry_1d = 5 if ind1970 >= 507 & ind1970 <= 699 
* Aggregate FIRE, Bus & Repair, Pro & Related (excl Ed & Health)
replace industry_1d = 6 if ind1970 >= 707 & ind1970 <= 719 /* FIRE */
replace industry_1d = 6 if ind1970 >= 727 & ind1970 <= 767 /* Bus Services & Repair */
replace industry_1d = 6 if ind1970 >= 869 & ind1970 <= 899 /* Pro & Related (excl Ed & Health) */
replace industry_1d = 6 if ind1970 == 849 /* Legal */
* Ed & Health Services
replace industry_1d = 7 if ind1970 >= 828 & ind1970 <= 848 /* Health */
replace industry_1d = 7 if ind1970 >= 857 & ind1970 <= 868 /* Ed */
* Aggregate Leisure & Hospitality & Personal Services
replace industry_1d = 8 if ind1970 >= 769 & ind1970 <= 799 /* Personal Services */
replace industry_1d = 8 if ind1970 >= 807 & ind1970 <= 817 /* Entertainment & Recreation */
replace industry_1d = 8 if ind1970 == 869 /* Museums, Art Galleries, and Zoos */
replace industry_1d = 8 if ind1970 == 669 /* Eating & Drinking Places */
* Public Admin & Military
replace industry_1d = 9 if ind1970 >= 907 & ind1970 <= 947 /* Public admin, no military listed */

* 1980 Census codes
* Ag & Mining
replace industry_1d = 1 if ind1980 >= 10 & ind1980 <= 50 
* Construction
replace industry_1d = 2 if ind1980 == 60 
* Manufacturing
replace industry_1d = 3 if ind1980 >= 100 & ind1980 <= 392 
* Transportation & Utilities & Communication
replace industry_1d = 4 if ind1980 >= 400 & ind1980 <= 472 
* Wholesale & Retail Trade
replace industry_1d = 5 if ind1980 >= 500 & ind1980 <= 691 
* Aggregate FIRE, Bus & Repair, Pro & Related (excl Ed & Health)
replace industry_1d = 6 if ind1980 >= 700 & ind1980 <= 712 /* FIRE */
replace industry_1d = 6 if ind1980 >= 721 & ind1980 <= 760 /* Bus Services & Repair */
replace industry_1d = 6 if ind1980 >= 861 & ind1980 <= 892 /* Pro & Related (excl Ed & Health) */
replace industry_1d = 6 if ind1980 == 841 /* Legal */
* Ed & Health Services
replace industry_1d = 7 if ind1980 >= 812 & ind1980 <= 840 /* Health */
replace industry_1d = 7 if ind1980 >= 842 & ind1980 <= 860 /* Ed */
* Aggregate Leisure & Hospitality & Personal Services
replace industry_1d = 8 if ind1980 >= 761 & ind1980 <= 791 /* Personal Services */
replace industry_1d = 8 if ind1980 >= 800 & ind1980 <= 802 /* Entertainment & Recreation */
replace industry_1d = 8 if ind1980 == 872 /* Museums, Art Galleries, and Zoos */
replace industry_1d = 8 if ind1980 == 641 /* Eating & Drinking Places */
* Public Admin & Military
replace industry_1d = 9 if ind1980 >= 900 & ind1980 <= 932 /* Public admin, no military listed*/

* 1990 Census codes
* see pp.21-27 of http://www.census.gov/people/io/files/techpaper2000.pdf
* Ag & Mining
replace industry_1d = 1 if ind1990 >= 10 & ind1990 <= 50 
* Construction
replace industry_1d = 2 if ind1990 == 60 
* Manufacturing
replace industry_1d = 3 if ind1990 >= 100 & ind1990 <= 392 
* Transportation & Utilities & Communication
replace industry_1d = 4 if ind1990 >= 400 & ind1990 <= 472 
* Wholesale & Retail Trade
replace industry_1d = 5 if ind1990 >= 500 & ind1990 <= 691 
* Aggregate FIRE, Bus & Repair, Pro & Related (excl Ed & Health)
replace industry_1d = 6 if ind1990 >= 700 & ind1990 <= 712 /* FIRE */
replace industry_1d = 6 if ind1990 >= 721 & ind1990 <= 760 /* Bus Services & Repair */
replace industry_1d = 6 if ind1990 >= 861 & ind1990 <= 893 /* Pro & Related (excl Ed & Health) */
replace industry_1d = 6 if ind1990 == 841 /* Legal */
* Ed & Health Services
replace industry_1d = 7 if ind1990 >= 812 & ind1990 <= 840 /* Health */
replace industry_1d = 7 if ind1990 >= 842 & ind1990 <= 860 /* Ed */
* Aggregate Leisure & Hospitality & Personal Services
replace industry_1d = 8 if ind1990 >= 761 & ind1990 <= 791 /* Personal Services */
replace industry_1d = 8 if ind1990 >= 800 & ind1990 <= 810 /* Entertainment & Recreation */
replace industry_1d = 8 if ind1990 == 872 /* Museums, Art Galleries, and Zoos */
replace industry_1d = 8 if ind1990 == 641 /* Eating & Drinking Places */
* Public Admin & Military
replace industry_1d = 9 if ind1990 >= 900 & ind1990 <= 932 /* Public admin */
replace industry_1d = 9 if ind1990 >= 940 & ind1990 <= 960 /* Military */

* 2002 Census codes
* See crosswalk back to 1990 at https://www.census.gov/people/io/files/IndustryCrosswalk90-00-02-07-12.xls
* Ag & Mining
replace industry_1d = 1 if ind2002 >= 170 & ind2002 <= 490
* Construction
replace industry_1d = 2 if ind2002 == 770
* Manufacturing
replace industry_1d = 3 if ind2002 >= 1070 & ind2002 <= 3990 
* Transportation & Utilities & Communication
replace industry_1d = 4 if ind2002 >= 6070 & ind2002 <= 6390  /* Trans & Warehousing */
replace industry_1d = 4 if ind2002 >= 570 & ind2002 <= 690  /* Utilities */
* 2002 codes create a Communication & Information Sector; modify these at the end, below
* Wholesale & Retail Trade
replace industry_1d = 5 if ind2002 >= 4070 & ind2002 <= 5790 
* Aggregate FIRE, Bus & Repair, Pro & Related (excl Ed & Health)
replace industry_1d = 6 if ind2002 >= 6870 & ind2002 <= 7190 /* FIRE */
replace industry_1d = 6 if ind2002 >= 7270 & ind2002 <= 7790 /* Pro */
replace industry_1d = 6 if ind2002 >= 9160 & ind2002 <= 9190 /* Pro */
replace industry_1d = 6 if ind2002 >= 8770 & ind2002 <= 8880 /* Repair */
replace industry_1d = 6 if ind2002 >= 8290 & ind2002 <= 8470 /* Pro (social services, but matches 70/80/90 coding) */
* Ed & Health Services
replace industry_1d = 7 if ind2002 >= 7860 & ind2002 <= 8270
* Aggregate Leisure & Hospitality & Personal Services
replace industry_1d = 8 if ind2002 >= 8890 & ind2002 <= 9090 /* Personal Services */
replace industry_1d = 8 if ind2002 == 9290 /* Personal Services */
replace industry_1d = 8 if ind2002 >= 8560 & ind2002 <= 8690 /* A&E, Accom, Restaurants */
* Public Admin & Military
replace industry_1d = 9 if ind2002 >= 9370 & ind2002 <= 9590 /* Public admin */
replace industry_1d = 9 if ind2002 >= 9670 & ind2002 <= 9890 /* Military */
* To be more consistent with earlier years, modify using Census crosswalk:
* https://www.census.gov/people/io/files/IndustryCrosswalk90-00-02-07-12.xls
* First clean up information/communication sectors
replace industry_1d = 3 if ind2002 == 6470 | ind2002 == 6480 /* newpaper and book publishing -> manufacturing */
replace industry_1d = 6 if ind2002 == 6490 /* software publishing -> bus services */
replace industry_1d = 8 if ind2002 == 6570 /* motion pictures -> leisure */
replace industry_1d = 6 if ind2002 == 6590 /* sound recording -> bus services */
replace industry_1d = 4 if ind2002 >= 6670 & ind2002 <= 6692 /* radio, tv, tele, internet -> communication */
replace industry_1d = 7 if ind2002 == 6770 /* libraries -> ed */
replace industry_1d = 6 if ind2002 == 6780 | ind2002 == 6695 /* other info & data -> bus services */
* Now clean up other miscellaneous industries
replace industry_1d = 1 if ind2002 == 7480 /* vet services -> ag */
replace industry_1d = 1 if ind2002 == 7770 /* landscape services -> ag */
replace industry_1d = 3 if ind2002 == 270 /* logging -> manuf */
replace industry_1d = 5 if ind2002 == 1190 /* retail bakery -> retail trade */
replace industry_1d = 8 if ind2002 == 7170 /* video rental */

tab industry_1d, gen(ind_)
drop industry_1d ind1970 ind1980 ind1990 ind2002


* CREATE CPS BASIC STATE X DATE CELLS 
* Define Demographic Group of Interest
local cpsgroup1 "age >= 16 & age <= 19"

gen quarter = quarter(dofm(ym(year,month)))
gen date = yq(year,quarter)
format date %tq


* LABOR FORCE
* generate urate for older workers: 25-64
gen urate = unemp if (unemp == 1 | emp == 1) & (age >= 25 & age <= 64)


* Prepare data for collapsing
forvalues k = 1 / 1 {
	gen erate_group`k' = emp == 1 if emp ~= . & `cpsgroup`k''
	gen whiterate_group`k' = white == 1 if white ~= . & `cpsgroup`k''
	gen blackrate_group`k' = black == 1 if black ~= . & `cpsgroup`k''
	gen femrate_group`k' = female == 1 if female ~= . & `cpsgroup`k''
	gen married_group`k' = married == 1 if female ~= . & `cpsgroup`k''
	gen poprate_group`k' = `cpsgroup`k''
}
collapse (mean) erate_group* ind_* whiterate_group* blackrate_group* femrate_group* married_group* poprate_group* urate unmem college [aw=wgt], by(state date) fast

* GEOGRAPHY
rename state censusnum
merge m:1 censusnum using ${cleandata}state_names.dta, nogenerate assert(3) keepusing(statefipsnum)
drop censusnum

compress
save ${cleandata}cpsbasic_statelevel.dta, replace


* LOAD MORG DATA
forvalues year = `beginyear'/`endyear' {
	local digits = substr("`year'",3,2)
	use "${morgdata}morg`digits'", clear
	keepifexist `morgusevarlist'
	compress
	tempfile morg`year'
	save `morg`year''
}
forvalues year = `beginyear'/`endyear' {
	if `year' == `beginyear' use `morg`year''
	else append using `morg`year''
}


* KEEP ONLY 16+
keep if age >= 16 & age ~= .

/* self-employed indicator */
gen selfemp = .
replace selfemp = 1 if class94 == 6 | class94 == 7	/* 1994 + */

/* topcode adjustment: multiply top-coded values by 1.5 */
gen _product = uhourse * earnhre
gen earnhre_topcoded = .
gen earnwke_topcoded = .
replace earnhre_topcoded = 1 if 1979 <= year & year <= 1984 & earnhre >= 9999 & earnhre ~=.
replace earnhre_topcoded = 1 if 1985 <= year & _product >= 192307 & _product ~=.
replace earnwke_topcoded = 1 if 1979 <= year & year <= 1988 & earnwke >= 999 & earnwke ~=.
replace earnwke_topcoded = 1 if 1989 <= year & year <= 1997 & earnwke >= 1923 & earnwke ~=.
replace earnwke_topcoded = 1 if 1998 <= year & earnwke >= 2884 & earnwke ~=.

/* calculate hourly wage */
gen wage = earnhre / 100 if paidhre == 1
replace wage = earnwke / uhourse if paidhre ~= 1

gen wage_topcoded = .
replace wage_topcoded = 1 if earnhre_topcoded == 1 & paidhre == 1
replace wage_topcoded = 1 if earnwke_topcoded == 1 & paidhre ~= 1

/* mark folks with imputed earnings */
/* imputed hourly wages for hourly wage earners */
gen byte paidhre_allocated = 0
replace paidhre_allocated = 1 if I25c > 0 & I25c ~=.

/* imputed weekly earnings for non-hourly wage earners */
gen byte earnwke_allocated = 0 
replace earnwke_allocated = 1 if I25d > 0 & I25d ~=.

gen byte allocated = 0 
replace allocated = 1 if paidhre == 1 & paidhre_allocated == 1
replace allocated = 1 if paidhre ~= 1 & earnwke_allocated == 1

/* gender indicators */
gen byte female = sex == 2
gen byte male = female == 0

/* union*/
gen byte unmem = 0 if unionmme ~= .
replace unmem = 1 if unionmme == 1
gen byte uncov = 0 if unioncov ~= .
replace uncov = 1 if unioncov == 1
gen byte union = 0 if unmem ~= .
replace union = 1 if unmem == 1
replace union = 1 if uncov == 1

/* ownership */
gen byte private = class94 == 4 | class94 == 5
gen byte public = class94 >= 1 & class94 <= 3

/* Weights */
* annual conversion
replace earnwt = earnwt / 12

/* dates */
rename intmonth month

gen quarter = quarter(dofm(ym(year,month)))
gen date = yq(year,quarter)
format date %tq

* create wage sample
drop if selfemp == 1
drop if wage_topcoded == 1
drop if wage == 0


* CREATE CPS MORG STATE X DATE CELLS 
local cpsgroup1 "age >= 16 & age <= 19"
forvalues k = 1 / 1 {
	gen wage_group`k' = wage if `cpsgroup`k''
}
collapse (mean) wage_group* [aw=earnwt], by(state date) fast
rename state censusnum
merge m:1 censusnum using ${cleandata}state_names, nogenerate assert(3) keepusing(statefipsnum)
drop censusnum
compress
save ${cleandata}cpsmorg_statelevel.dta, replace


