* RUN SINGLE TREATMENT PROCEDURES FOR ALL STATES (ACTUAL AND PLACEBOS)
* iterating over procedures, treatment events, and demo groups
* eventually save results as dta

capture log close 
capture log using ${do}create_baseresults.log, text replace
di "start time = " "$S_TIME"
capture log close

use ${cleandata}regready_macropanel_pre99_post99.dta, clear

* create the iteration id
egen iteration = group(control treatmentid statefipsnum)
* these data will be used by results_batchjob.do
save ${indresults}pre99_post99.dta, replace

* grab the values over which R/snow will iterate
qui sum iteration if treated == 1
local actuals_itmin = r(min)
local actuals_itmax = r(max)
qui sum iteration if treated == 0
local placebos_itmin = r(min)
local placebos_itmax = r(max)

* check if set_globalmacros.do has identified to run: actuals or placebos or both
foreach ttype in actuals placebos {
	if $`ttype' == 1 {
		use ${indresults}pre99_post99.dta, clear
		foreach procedure in $procedurelist {
			foreach outcome in $outcomelist {
				foreach group of numlist $demogroupnumlist {

					* write R script, which will use R's multicore to call instances of stata
					* iterating over iteration numbers
					write_r_script, procedure(`procedure') itbegin(``ttype'_itmin') itend(``ttype'_itmax') group(`group') outcome(`outcome') cpus($cpus)

					* run the R script, which calls stata-mp -b results_batchjob.do `options'
					* this will now complete all iterations via snowfall
					cd ${do}
					shell R CMD BATCH multicore_R_baseresults.R /dev/null

				} // group
			} // outcome
		} // procedure 
	} // if $ttype=1
} // ttype


capture log close 
capture log using ${do}create_baseresults.log, text append
di "end time = " "$S_TIME"
capture log close


