capture program drop figuremaker
program define figuremaker
foreach name in  allscatter mwchangers matchquality pldisttest rankdisttest overalltrend {

	local graphfont "Sans"
	graph set eps fontface "`graphfont'"
	graph set eps fontfaceserif "`graphfont'"
	graph set eps  /*echo back preferences*/

	create_figure_`name'
}
end




capture program drop create_figure_mwchangers
program define create_figure_mwchangers

use ${cleandata}mwchangers.dta, clear
sort stateabb date
gen event = _n
list stateabb date mw

gen all = 1
egen mwchangecount = total(all), by(stateabb)
egen tag = tag(stateabb)
replace mwchangecount = 0 if mwchangecount == .

keep if mwchangecount > 0
gen mwchanger = 1
keep stateabb date mwchanger

gen fedincrease = 1 if date == tq(1979q1) | date == tq(1980q1) | date == tq(1981q1) | date == tq(1990q2) | date == tq(1991q2) | date == tq(1996q4) | date == tq(1997q3) | date == tq(1997q4) | date == tq(2007q3) | date == tq(2008q3) | date == tq(2009q3)

capture log close
capture log using ${tabledata}mwchange_counts.log, text replace
qui sum date
di "number of quarterly min wage changes = " r(N)
qui sum date if fedincrease ~= 1
di "number of quarterly min wage changes that do not coincide with federal = " r(N)
tab stateabb if fedincrease ~= 1 , nofreq
di "number of states that have statutory min wage changes = " r(r)
capture log close



egen _notonlyfedmwchanger = max(mwchanger) if fedincrease ~=1, by(stateabb)
egen notonlyfedmwchanger = max(_notonlyfedmwchanger), by(stateabb)
keep if notonlyfedmwchanger == 1
drop fedincrease *notonlyfedmwchanger



gsort -stateabb
spell stateabb
tab stateabb, nofreq
local numstates = r(r)
gen stateindex = _spell - floor(r(r)/2)
sum stateindex
local stateindexmin = r(min)
local stateindexmax = r(max)
local stateindexplus = `stateindexmax' + 3
labmask stateindex, values(stateabb)


preserve
duplicates drop stateabb, force
keep stateabb stateindex
tempfile stateindices
save `stateindices'

keep stateabb
levelsof stateabb, local(stateabblist)
local begdate = tq(1980q2)
local enddate = tq(2013q4)
gen date = tq(1980q1)
foreach stateabb in `stateabblist' {
	forvalues i = `begdate' / `enddate' {
		moreobs 1
		replace date = `i' if date == .
		replace stateabb = "`stateabb'" if stateabb == ""
	}
}
tempfile statetimetemplate
save `statetimetemplate'
restore
merge 1:1 stateabb date using `statetimetemplate', assert(2 3) nogenerate
merge m:1 stateabb using `stateindices', assert(3) nogenerate


gen fedincrease = .
gen fedmw = .

replace fedincrease = 1 if date == tq(1979q1)
replace fedmw = 2.90 if date == tq(1979q1)
replace fedincrease = 1 if date == tq(1980q1)
replace fedmw = 3.10 if date == tq(1980q1)
replace fedincrease = 1 if date == tq(1981q1)
replace fedmw = 3.35 if date == tq(1981q1)
replace fedincrease = 1 if date == tq(1990q2)
replace fedmw = 3.80 if date == tq(1990q2)
replace fedincrease = 1 if date == tq(1991q2)
replace fedmw = 4.25 if date == tq(1991q2)
replace fedincrease = 1 if date == tq(1996q4)
replace fedmw = 4.75 if date == tq(1996q4)
replace fedincrease = 1 if date == tq(1997q3)
replace fedmw = 5.15 if date == tq(1997q3)
replace fedincrease = 1 if date == tq(2007q3)
replace fedmw = 5.85 if date == tq(2007q3)
replace fedincrease = 1 if date == tq(2008q3)
replace fedmw = 6.55 if date == tq(2008q3)
replace fedincrease = 1 if date == tq(2009q3)
replace fedmw = 7.25 if date == tq(2009q3)
* using quarterly averages to define minimum wage spells
* will cause the Sep 1997 min wages increase to appear as two increases
* one of which we'll remove from the picture for aesthetic reasons
replace fedincrease = 1 if date == tq(1997q4)

levelsof date if fedincrease == 1 & date ~= tq(1997q4), local(fedincreases)


* stupid hack to get Stata to make the year labels look nice
local datemin = tq(1980q1)
local datemax = tq(2013q4)
forvalues i = `datemin'/`datemax' {
	moreobs 1
	replace date = `i' if date == .
}
gen year = year(dofq(date))
labmask date, values(year)
drop if stateabb == ""



preserve
use ${cleandata}finaltreatmentsandcontrols_prelength99_postlength99.dta, clear
keep if treated == 1
egen _treatdate = min(date) if post == 1, by(treatmentid)
egen treatdate = max(_treatdate), by(treatmentid)
gen startevent = 1 if date == treatdate 
keep stateabb date treatdate startevent treatmentid prewindow postwindow
tempfile usedevents
save `usedevents'
restore
merge 1:m stateabb date using `usedevents', nogenerate 
replace startevent = 0 if mwchanger == 1 & startevent == .

* we will need to use the mlabgap option to align the marker label with the date 
* (instead of the invisible marker symbol)
local mlabgap mlabgap(-2.9)
* create vertical lines for fed increases
local xlines xline(`fedincreases', lpattern(l) lcolor(gs14))
* show fed min wage as text
local fedmwlabels ""
foreach date of numlist `fedincreases' {
	sum fedmw if date == `date'
	local xpos = `date'
	if `date' == tq(1980q1) | `date' == tq(1990q2) | `date' == tq(1996q4) | `date' == tq(2007q3) {
		local placement placement(c)
	}
	else if `date' == tq(1981q1) | `date' == tq(1991q2) | `date' == tq(1997q3) | `date' == tq(2009q3) {
		local placement placement(e)
	}
	else local placement placement(c)
	if `date' == tq(2007q3) local xpos = `date' - 1
	if `date' == tq(2008q3) local xpos = `date' + 0.75
	local fedmw: di %3.2f r(mean)
	local fedmwlabels `fedmwlabels' text(`stateindexplus' `xpos' `"$`fedmw'"', size(vsmall) color(gs9) `placement')
}
local postfedmw = tq(2009q3) + 5
local fedmwlabels `fedmwlabels' text(`stateindexplus' `postfedmw' "= Federal Minimum", size(vsmall) color(gs9) placement(e))
local graphoptions yscale(off) ylabel(`stateindexmin'(1)`stateindexmax',nogrid) xlabel(`datemin'(12)`datemax', valuelabel labsize(small)) ysize(4) xsize(6.5) graphregion(color(white) /*margin(t=3 b=0 r=3 l=2)*/) plotregion(color(white) margin(t=6)) ytitle("") xtitle("") legend(off)


drop if fedincrease == 1
scatter stateindex date if startevent == 0, msymbol(i) mlab(stateabb) mlabsize(2.75) mlabcolor(gs9) `mlabgap' || scatter stateindex date if startevent == 1, xlabel(,valuelabel) msymbol(i) mlab(stateabb) mlabsize(2.75) mlabcolor(black) `mlabgap' `graphoptions' `xlines'  `fedmwlabels'

graphexportpdf ${figures}mwchangers_part1.pdf, dropeps


use if treated == 1 using ${cleandata}finaltreatmentsandcontrols_prelength99_postlength99.dta, clear
egen _treatdate = min(date) if post == 1, by(treatmentid)
egen treatdate = max(_treatdate), by(treatmentid)
xtset treatmentid date
gen int intmw = round(mw * 100)
tsspell intmw
gen mwchange = _seq == 1 & _spell > 1
merge m:1 stateabb using `stateindices', keep(3)



* modify the state index to more easily display Hawaii
* HI 2006q1
replace stateabb = "" if treatmentid == 7
replace stateindex = stateindex - 0.5 if treatmentid == 8

gen extradate = .
replace extradate = tq(1990q4) if treatdate < tq(1990q1)
replace extradate = tq(1997q1) if treatdate > tq(1990q1) & treatdate < tq(1996q1)
replace extradate = tq(2008q1) if treatdate > tq(1996q1)


local prerarealist ""
local prerareaopts sort lcolor(navy) fcolor(navy)
forvalues i = 1 / 33 {
	sum stateindex if treatmentid == `i'
	gen preevent`i'low = r(mean) - 0.1 if treatmentid == `i' & date >= treatdate - prewindow + 1 & date <= treatdate
	gen preevent`i'hi = r(mean) + 0.1 if treatmentid == `i' & date >= treatdate - prewindow + 1 & date <= treatdate
	if `i' == 1 local prerarealist rarea preevent`i'low preevent`i'hi date, `prerareaopts'
	else local prerarealist `prerarealist' || rarea preevent`i'low preevent`i'hi date, `prerareaopts'
}
local postrarealist ""
local postrareaopts sort lcolor(maroon) fcolor(maroon)
forvalues i = 1 / 33 {
	sum stateindex if treatmentid == `i'
	gen postevent`i'low = r(mean) - 0.1 if treatmentid == `i' & date >= treatdate 
	gen postevent`i'hi = r(mean) + 0.1 if treatmentid == `i' & date >= treatdate 
	if `i' == 1 local postrarealist rarea postevent`i'low postevent`i'hi date, `postrareaopts'
	else local postrarealist `postrarealist' || rarea postevent`i'low postevent`i'hi date, `postrareaopts'
}


* stupid hack to get Stata to make the year labels look nice
local datemin = tq(1980q1)
local datemax = tq(2013q4)
forvalues i = `datemin'/`datemax' {
	moreobs 1
	replace date = `i' if date == .
}
gen year = year(dofq(date))
labmask date, values(year)
drop if stateindex == .

egen tag = tag(treatmentid)

graph twoway `prerarealist' || `postrarealist' || scatter stateindex date if mwchange == 1, msymbol(o) mcolor(maroon) `graphoptions' || scatter stateindex extradate if tag == 1, mlab(stateabb) mlabgap(-2.9) mlabcolor(black) msymbol(i) `xlines' `fedmwlabels'
graphexportpdf ${figures}mwchangers_part2.pdf, dropeps


end




capture program drop create_figure_matchquality
program define create_figure_matchquality


foreach proc in 3 {
	foreach outvar in wage erate {
		use if group == 1 using ${aggresults}synth`proc'`outvar'statistics_allopt_ranked_byevent, clear
		gen _treatedrmspe = sqrt(premspe) if treated == 1
		egen _ranknegrmspe = rank(-_treatedrmspe) if treated == 1
		egen treatedrmspe = max(_treatedrmspe), by(event)
		egen ranknegrmspe = max(_ranknegrmspe), by(event)
		keep event statecount preelast pre16elast pre16elastprank preelastprank postelast postelastprank treatedrmspe ranknegrmspe treated placebo
		gen id = 1
		tempfile totrim
		save `totrim'
		forvalues i = 0 / 11 {
			use `totrim', clear
			keep if ranknegrmspe > `i'
			sum treatedrmspe if ranknegrmspe == `i'
			local rmspecut = r(mean)
			tempfile input
			save `input'
			tempfile output
			tempfile outputHL
			invertstats, inputdata(`input') outputaggregate(`output') statlist(postelast pre16elast preelast) aggcutoffs(${tabledata}pranksigcutoffs.dta) aggstatlist(mean) increment(0.001) id(id) cilev(95)
			invertstats, inputdata(`input') outputaggregate(`outputHL') statlist(postelast pre16elast preelast) aggcutoffs(${tabledata}pranksigcutoffs.dta) aggstatlist(mean) increment(0.001) id(id) cilev(95) hodgeslehmann
			use `outputHL', clear
			egen postelastHL = rowmean(postelastmeanloci95 postelastmeanhici95)
			egen preelastHL = rowmean(preelastmeanloci95 preelastmeanhici95)
			egen pre16elastHL = rowmean(pre16elastmeanloci95 pre16elastmeanhici95)
			keep postelastHL preelastHL pre16elastHL
			gen trim = `i'
			tempfile HL
			save `HL'
			use `output', clear
			gen trim = `i'
			merge 1:1 trim using `HL', assert(3) nogenerate
			gen rmspecut = `rmspecut'
			tempfile trim`i'
			save `trim`i''
		}
		forvalues i = 0/11 {
			if `i' == 0 use `trim`i''
			else append using `trim`i''
		}
		save ${tabledata}synth`proc'prermspetrimmed_`outvar'.dta, replace


	}



	*/

	foreach outvar in erate wage {
	
		use ${tabledata}synth`proc'prermspetrimmed_`outvar', clear
		foreach prepost in pre post {
	
			if "`prepost'" == "pre" local preposttitle Pre-treatment	
			if "`prepost'" == "post" local preposttitle Post-treatment	
			if "`outvar'" == "wage" {
				if "`prepost'" == "post" local yrange 0(0.1)0.5
				if "`prepost'" == "pre" local yrange -0.10(0.05)0.10
				local ylabel ylabel(`yrange',glcolor(gs15) labsize(vsmall) gmin gmax)
				local ytitle "`preposttitle' Wage Elasticity"
				local legendoptions off
			}
			if "`outvar'" == "erate" {
				local legendoptions pos(12) ring(0) cols(1) size(vsmall) region(lcolor(white)) bmargin(t=0) order(1 3 4) label(1 "95% HL CI") label(3 "HL elasticity") label(4 "Mean elasticity")
				if "`prepost'" == "post" local yrange -0.30(0.1)0.20
				if "`prepost'" == "pre" local yrange -0.10(0.05)0.10
				local ylabel ylabel(`yrange',glcolor(gs15) labsize(vsmall) gmin gmax)
				local ytitle "`preposttitle' Employment Elasticity"
			}

			scatter `prepost'elastmeanhici95 `prepost'elastmeanloci95 trim, mcolor(navy navy) msymbol(o o) connect(l l) lcolor(/*gs14 gs14*/ navy navy) lpattern(- -) || scatter `prepost'elastHL `prepost'elastmean trim, sort(trim) connect(l l) lpattern(l l) lcolor(navy maroon) mcolor(navy maroon) msymbol(o s) legend(`legendoptions') `ylabel' xlabel(0(1)11,labsize(vsmall) valuelabel) graphregion(color(white)) plotregion(style(none) margin(l=0 r=2 b=0 t=1)) xtitle(Number of trimmed events, size(small) color(black) margin(t=2)) ytitle(`ytitle', size(small) color(black) margin(r=2)) ysize(3) xsize(3)
			graphexportpdf ${figures}synth`proc'prermspetrimmed_`prepost'`outvar'.pdf, dropeps

		}
	
	}
}
end



capture program drop create_figure_overalltrend
program define create_figure_overalltrend



foreach outvar in erate wage {
	use ${compresults}synth${prefproc}`outvar'results_allopt_actuals.dta, clear
	append using ${compresults}synth${prefproc}`outvar'results_allopt_placebos.dta
	keep if preconfig == 99 & postconfig == 99 & group == 1
	egen maxmwtreatment = max(mwtreatment), by(event)
	egen minmwtreatment = min(mwtreatment), by(event)
	gen pctmwtreatment = maxmwtreatment/minmwtreatment - 1
	gen negpost = post
	recode negpost (1 = 0) (0 = -1)
	gen negdate = -date
	gen time = .
	bysort event statefipsnum (date): replace time = sum(post)
	bysort event statefipsnum (negdate): replace time = sum(negpost) if post == 0
	replace time = time - 1 if post == 1
	replace time = floor(time/4)
	gen diff = y_treated - y_synthetic
	gen elast = (diff/y_synthetic) / pctmwtreatment

	collapse (mean) elast treated placebo mwtreatment, by(time event stateabb statefipsnum)

* only one event at time = -8, so going to drop this from the picture (code doesn't calculate CI correctly)
drop if time == -8

	if "`outvar'" == "erate" {
		preserve
		keep if treated == 1
		egen _premw = mean(mwtreatment) if time < 0, by(event)
		egen premw = max(_premw), by(event)
		gen meanpctmwchange = mwtreatment/premw - 1
		egen meannumevents = count(event), by(time)
		collapse (mean) meanpctmwchange meannumevents, by(time)
		save ${tabledata}overalltrend_mw.dta, replace		
		restore
	}

	egen statecount = count(statefipsnum), by(event time)
	egen elastrank = rank(elast), by(time event)
	gen elastprank = elastrank / (statecount + 1)	
	tempfile input
	save `input'
	tempfile output
	tempfile outputHL
	invertstats, inputdata(`input') outputaggregate(`output') statlist(elast) aggstatlist(mean) aggcutoffs(${tabledata}pranksigcutoffs.dta)  increment(0.001) id(time) cilev(95)
	invertstats, inputdata(`input') outputaggregate(`outputHL') statlist(elast) aggstatlist(mean) aggcutoffs(${tabledata}pranksigcutoffs.dta)  increment(0.001) id(time) cilev(95) hodgeslehmann

	use `outputHL', clear
	egen elastHL = rowmean(elastmeanloci95 elastmeanhici95)
	keep elastHL time
	tempfile HL
	save `HL'

	use `output', clear
	merge 1:1 time using `HL', assert(3) nogenerate

	save ${tabledata}overalltrend_`outvar'_ci.dta, replace
}
*/


foreach outvar in wage erate {
	use ${tabledata}overalltrend_`outvar'_ci.dta, clear

	gen timelabel = ""
	forvalues i = 0 / 2 {
		local ilo = `i' * 4
		local ihi = `ilo' + 3
		replace timelabel = "(`ilo',`ihi')" if time == `i'
	}
	forvalues i = -8/-1 {
		local ilo = (`i'+1)*4 - 1
		local ihi = `ilo' - 3
		replace timelabel = "(`ihi',`ilo')" if time == `i'
	}
	labmask time, values(timelabel)

	if "`outvar'" == "wage" {
		local yrange ylabel(-0.7(0.1)0.7, glcolor(gs15) labsize(vsmall) gmin gmax)
		local legendoptions pos(12) ring(0) cols(1) size(small) region(lcolor(white)) order(4 3 1) label(1 "95% HL CI") label(3 "HL elasticity") label(4 "Mean elasticity")
		local ytitle "Wage Elasticity"
	}
	if "`outvar'" == "erate" {
		local legendoptions pos(12) ring(0) cols(1) size(small) region(lcolor(white)) order(4 3 1) label(1 "95% HL CI") label(3 "HL elasticity") label(4 "Mean elasticity")
		local yrange ylabel(-0.5(0.1)0.5, glcolor(gs15) labsize(small) gmin gmax)
		local ytitle "Employment Elasticity"
	}
	line elastmeanhici95 elastmeanloci95 time, lcolor(navy navy) lpattern(- -) || line elastHL elastmean time, sort(time) lpattern(l l) lcolor(navy maroon) legend(`legendoptions') `yrange' xlabel(-7(1)2,labsize(small) valuelabel) xline(-0.5,lpattern(l) lcolor(gs11)) yline(0,lpattern(l) lcolor(gs11)) graphregion(color(white)) plotregion(style(none) margin(l=0 r=2 b=0 t=1)) xtitle(Quarters since treatment, size(medsmall) color(black) margin(t=2)) ytitle(`ytitle', size(medsmall) color(black) margin(r=2)) ysize(3) xsize(6.5)
	graphexportpdf ${figures}overallelasticitytrend_`outvar'.pdf, dropeps
}

use ${tabledata}overalltrend_mw, clear

gen timelabel = ""
forvalues i = 0 / 2 {
	local ilo = `i' * 4
	local ihi = `ilo' + 3
	replace timelabel = "(`ilo',`ihi')" if time == `i'
}
forvalues i = -8/-1 {
	local ilo = (`i'+1)*4 - 1
	local ihi = `ilo' - 3
	replace timelabel = "(`ihi',`ilo')" if time == `i'
}
labmask time, values(timelabel)

local legendoptions pos(11) ring(0) cols(1) size(small) region(lcolor(white)) order(1 2) label(2 "Mean minimum wage change") label(1 "Mean number of events") bmargin(t=6 l=8)

line meannumevents time, yaxis(1) lcolor(navy) lpattern(l) legend(`legendoptions') ylabel(0(5)35, glcolor(gs15) labsize(small) gmin gmax axis(1)) ytitle("Number of events", size(medsmall) color(black) margin(r=2) axis(1)) xlabel(-7(1)2,labsize(small) valuelabel) xline(-0.5,lpattern(l) lcolor(gs11)) graphregion(color(white)) plotregion(style(none) margin(l=0 r=2 b=0 t=1)) xtitle(Quarters since treatment, size(medsmall) color(black) margin(t=2))  ysize(3) xsize(6.5) || line meanpctmwchange time, lcolor(maroon) lpattern(l) legend(`legendoptions') yaxis(2) ylabel(0(0.05)0.2, glcolor(gs15) labsize(small) gmin gmax axis(2)) ytitle("Minimum wage change (percent)", size(medsmall) color(black) margin(l=2) axis(2))
graphexportpdf ${figures}overallmwtrend.pdf, dropeps




end


capture program drop create_figure_pldisttest
program define create_figure_pldisttest

foreach out in EPOP Wage {
	if "`out'" == "EPOP" {
		local outvar erate
		local xtitle Donor employment elasticities
		local legendoptions ring(0) pos(3) cols(1) region(lcolor(white)) bmargin(l=6 r=0 b=0 t=0) symxsize(*1.5) size(medsmall) order(1 "Donors" 2 "Normal")
	}
	if "`out'" == "Wage" {
		local outvar wage
		local xtitle Donor wage elasticities
		local legendoptions "off"
	}

	use if preconfig == 99 & postconfig == 99 & group == 1 & treated == 0 using ${aggresults}synth${prefproc}`outvar'statistics_allopt_ranked_byevent.dta, clear
	sum postelast, d
	local sd : di %04.3f r(sd)
	local mean : di %04.3f r(mean)
	local kurtosis : di %03.2f r(kurtosis)
	local N = r(N)
	swilk postelast
	local p : di %04.3f r(p)


	twoway kdensity postelast, n(`N') lcolor(gs0) lpattern(l) || function y=normalden(x,`mean',`sd'), lcolor(gs7) lpattern(-) range(-3 8) graphregion(color(white) margin(l=1 r=2 b=0 t=1)) plotregion(style(none)) legend(`legendoptions') xtitle(`xtitle',size(small)) ylabel(, glcolor(gs15)) xlabel(-3(1)8) ysize(3.5) xsize(6.5)
	graphexportpdf ${figures}pldisttest_`outvar'.pdf, dropeps

di "Placebo and normal distributions have standard deviation `sd'." 
di "Placebo sample has mean `mean', kurtosis = `kurtosis'. Normal distribution has mean `mean'." 
di "Shapiro-Wilk normality test p-value = `p'."

}

end



capture program drop create_figure_rankdisttest
program define create_figure_rankdisttest

foreach out in EPOP Wage {
	if "`out'" == "EPOP" {
		local outvar erate
		local xtitle "Employment elasticity percentile ranks"
		local legendoptions ring(0) pos(4) cols(1) region(lcolor(white)) bmargin(r=1 b=14 t=0) symxsize(*0.8) size(medium)
	}
	if "`out'" == "Wage" {
		local outvar wage
		local xtitle "Wage elasticity percentile ranks"
		local legendoptions "off"
	}

	use if preconfig == 99 & postconfig == 99 & group == 1 & treated == 1 using ${aggresults}synth${prefproc}`outvar'statistics_allopt_ranked_byevent.dta, clear
	cumul postelastprank, gen(cumul)
	gen uniform = postelastprank
	lab var uniform "Uniform CDF"
	lab var cumul "Sample CDF"
	ksmirnov postelastprank = postelastprank
	local ksp : di %04.3f r(p_cor)

	a2 postelastprank, dist(uniform)
	local a2 : di %04.3f ${S_4}
	
	line cumul postelastprank, sort(postelastprank cumul) lcolor(navy) lpattern(l) || function y=x, lcolor(gs7) lpattern(-) range(0 1) name(`outvar', replace) graphregion(color(white)) plotregion(color(white)) legend(`legendoptions') xtitle(`xtitle', margin(0 0 0 2) size(medium) color(black)) ylabel(, glcolor(gs15)) xlabel(0(.2)1) text(0.09 0.83 "K-S p-value = `ksp'", size(medium)) text(0.04 0.83 "A-D p-value = `a2'", size(medium)) ysize(3.25) xsize(3.25) legend(off)

	
	use if preconfig == 99 & postconfig == 99 & group == 1 using ${aggresults}synth${prefproc}`outvar'statistics_allopt_ranked_byevent.dta, clear
	sum postelast if placebo == 0
	gen meaneffect = r(mean)
	gen newpostelast = postelast if placebo == 1
	replace newpostelast = postelast - meaneffect if placebo == 0
	egen newrank = rank(newpostelast), by(event)
	keep if treated == 1
	gen newprank = newrank / (statecount + 1)
	gen newuniform = newprank
	cumul newprank, gen(newcumul)
	lab var newuniform "Uniform CDF"
	lab var newcumul "Sample CDF"
	ksmirnov newprank = newprank
	local ksp : di %04.3f r(p_cor)

	a2 newprank, dist(uniform)
	local a2 : di %04.3f ${S_4}
	
	if "`out'" == "EPOP" {
		local outvar erate
		local xtitle "Employment elasticity percentile ranks"
	}
	if "`out'" == "Wage" {
		local outvar wage
		local xtitle "Wage elasticity percentile ranks"
	}
	line newcumul newuniform newprank, sort(newprank newcumul) lcolor(navy gs7) lpattern(l -) name(hetero`outvar', replace) graphregion(color(white)) plotregion(color(white)) legend(off) xtitle(`xtitle', margin(0 0 0 2) size(medium) color(black)) ylabel(, glcolor(gs15)) xlabel(0(.2)1) text(0.09 0.83 "K-S p-value = `ksp'", size(medium)) text(0.04 0.83 "A-D p-value = `a2'", size(medium)) ysize(3.25) xsize(3.25)
}

graph combine erate wage, graphregion(color(white)) plotregion(color(white)) ysize(3.25) xsize(6.5) rows(1) cols(2) name(noeffect, replace)
graphexportpdf ${figures}rankdisttest_zeroeffect.pdf, dropeps
graph combine heteroerate heterowage, graphregion(color(white)) plotregion(color(white)) ysize(3.25) xsize(6.5) rows(1) cols(2) name(heteroeffect, replace)
graphexportpdf ${figures}rankdisttest_meaneffect.pdf, dropeps



end




capture program drop create_figure_allscatter
program define create_figure_allscatter

foreach out in erate wage {
	use if treated == 1 using ${aggresults}synth${prefproc}`out'statistics_allopt_ranked_byevent.dta, clear
	gen outcome = "`out'"
	gen eventtype = "individual"
	keep event stateabb treatdate postelast postelastprank outcome eventtype
	sum postelast, d
	local postelastmedian = r(p50)
	tempfile `out'
	save ``out''

	use ${tabledata}synth${prefproc}`out'statistics_allopt_aggregatedci.dta, clear
	gen outcome = "`out'"
	rename postelastmeanHL postelastHL
	gen postelastmedian = `postelastmedian'
	rename postelastmeanloci95 postelastlo
	rename postelastmeanhici95 postelasthi
	keep outcome postelastHL postelastmean postelastmedian postelastprank postelastlo postelasthi
	reshape long postelast postelastprank postelastlo postelasthi, i(outcome) j(eventtype) string	
	tempfile `out'agg
	save ``out'agg'
}

use `erate', clear
append using `wage'

append using `erateagg'
append using `wageagg'
reshape wide postelast postelastprank, i(eventtype event) j(outcome) string



#delimit ;
scatter postelasterate postelastwage if event ~= ., 
msymbol(i) mlab(stateabb) mlabcolor("99 99 99") mlabsize(medsmall) mlabgap(-3.5) ||
scatter postelasterate postelastwage if eventtype == "mean", msymbol(S) msize(medlarge) mcolor(maroon) ||
scatter postelasterate postelastwage if eventtype == "HL", msymbol(O) msize(medlarge) mcolor(navy)
graphregion(color(white)) plotregion(style(none) margin(l=0 r=2 b=0 t=1)) ysize(4) xsize(6.5) xtitle("Wage Elasticity", color(black) margin(t=2)) ytitle("Employment Elasticity", color(black) margin(l=0 r=2)) yline(0, lcolor(gs11)) xline(0, lcolor(gs11)) ylabel(-1.5(0.5)1.0,glcolor(none))  xlabel(-0.25(0.25)1.50) ||
function y=-x, lcolor(gs11) lpattern(-) range(-0.25 1.5) 
legend(ring(0) pos(3) cols(1) region(lcolor(white)) bmargin(t=15) symxsize(*0.8) label(2 "Mean elasticity") label(3 "HL elasticity") label(4 "Unitary elastic demand" ) order(2 3 4 6) size(small));
#delimit cr;
graphexportpdf ${figures}figure_allscatter.pdf, dropeps





end





**********************
*** PROGRAM SWITCH ***
**********************
figuremaker



