
* set the possible pre-/post-window configurations
local prelist 8 12 16 20 24 28 32
local postlist 4 6 8 10 12

* Set maximum date in our data
local maxdate = tq(2013q4)

use ${cleandata}mw_quarterly_1979_2013.dta, clear

* WE ARE NOT USING DC DUE TO EXTREMELY SMALL SAMPLE IN MORG
drop if stateabb == "DC"

tsset statefipsnum date



* create minimum wage spells
* use integer version of mw to calculate changes
gen int intmw = round(mw * 100)
tsspell intmw
egen _seqmax = max(_seq), by(statefipsnum _spell)
gen prevmw = L.mw
* save this data for merging later on

* L0change identifies whether there is a min wage increase
* in the same quarter
gen L0change = L1._seq == 1

tempfile mw_summary
save `mw_summary', replace

* now restrict data to changers only
keep if _seq == 1
drop if _spell == 1
* later too for other uses, we will want these mw changers data
save ${cleandata}mwchangers.dta, replace


* now restrict changers to those that satisfy pre-post windows
foreach pre of numlist `prelist' {
	foreach post of numlist `postlist' {

		use ${cleandata}mwchangers.dta, clear

		* set length restrictions, in quarters
		local postlength = `post'
		local prelength = `pre'

		* generate initial treatment variable,
		* which will eventually be replaced = 1 if restrictions satisfied
		gen byte treatment = 0
		tempfile potentialtreatments
		save `potentialtreatments', replace

		* implement prelength restriction on treatments
		local obsmax = _N
		qui forvalues obsnum = 1/`obsmax' {

			sum statefipsnum if _n == `obsnum'
			local treatstate = r(mean)
			sum date if _n == `obsnum'
			local treatbeg = r(mean)
			local pretreatbeg = r(mean) - `prelength'

			preserve
			use if statefipsnum == `treatstate' & date >= `pretreatbeg' & date < `treatbeg' using `mw_summary', clear
			sum _seqmax
			local seqmax = r(mean)	
			sum _spell
			local spelldiff = r(max) - r(min)
			sum L0change
			local L0change = r(mean)
			restore
			if `seqmax' >= `prelength' & `spelldiff' == 0 & `L0change' == 0 replace treatment = 1 if statefipsnum == `treatstate' & date == `treatbeg'
			save `potentialtreatments', replace
		}
		keep if treatment == 1

		* implement postlength restriction on treatments
		keep if date + `postlength' - 1 <= `maxdate'

		* do not include indexed min wage treatments
		drop if indexedwage == 1

		sort stateabb date
		gen int treatmentid = _n
		* save a dataset summarizing the treatments
		rename treatment treated
		gen control = treated == 0
		keep date stateabb statefipsnum date treatmentid treated
		
		tempfile tonlypre`pre'post`post' tcpre`pre'post`post'
		save `tonlypre`pre'post`post''

		* create a bunch of stacked panel datasets containing treated and donor states
		* do this by grabbing some info from the treatment summary data set
		* then load the minimum wage data set
		* then use the info to keep appropriate control states and the treated state
		* loop this procedure over all treated states, then save and stack panels
		use `tonlypre`pre'post`post'', clear
		local numberoftreatments = _N
		qui forvalues obsnum = 1/`numberoftreatments' {
			use if treatmentid == `obsnum' using `tonlypre`pre'post`post'', clear
			tab stateabb
			sum statefipsnum
			local treatstate = r(mean)
			sum date
			local treatbeg = r(mean)
			local pretreatbeg = `treatbeg' - `prelength'
			local posttreatend = `treatbeg' + `postlength' - 1
			use if date >= `pretreatbeg' & date <= `posttreatend' using `mw_summary', clear
			egen byte minspell = min(_spell), by(statefipsnum)
			egen byte maxspell = max(_spell), by(statefipsnum)
			gen byte spelldiff = maxspell - minspell
			* select the treated state and all states with no min wage change
			keep if spelldiff == 0 | statefipsnum == `treatstate'
			gen byte treated = statefipsnum == `treatstate'
			gen byte control = treated == 0
			gen byte post = date >= `treatbeg'
			gen int treatmentid = `obsnum'
			* add a variable containing the true minwage for the treatment state
			gen _mwtreatment = mw if statefipsnum == `treatstate'
			egen mwtreatment = max(_mwtreatment), by(date)
			keep date mw mwtreatment stateabb statefipsnum date treatmentid treated control post
			if `obsnum' == 1 save `tcpre`pre'post`post''
			else {
				append using `tcpre`pre'post`post''
				save `tcpre`pre'post`post'', replace
			}
		} // obsnum

		* count donors
		use `tcpre`pre'post`post'', clear
		egen _numdonors = count(statefipsnum) if control == 1, by(treatmentid date)
		egen numdonors = max(_numdonors), by(treatmentid)
		drop _numdonors
		save `tcpre`pre'post`post'', replace
		
		keep if treated == 1
		egen tag = tag(treatmentid)
		keep if tag == 1
		keep treatmentid numdonors
		merge 1:1 treatmentid using `tonlypre`pre'post`post'', keep(3) nogenerate
		save `tonlypre`pre'post`post'', replace
		
	} // post
} // pre


* create maximal window samples
* first put all the events together in one dataset
tempfile alltreatments alltreatmentsandcontrols
local counter = 0
foreach pre of numlist `prelist' {
	foreach post of numlist `postlist' {
		local counter = `counter' + 1
		
		* compile all treatments
		use `tonlypre`pre'post`post'', clear
		gen byte prewindow = `pre'
		gen byte postwindow = `post'
		keep stateabb statefipsnum date prewindow postwindow treatmentid
		if `counter' == 1 save `alltreatments', replace
		else {
			append using `alltreatments'
			save `alltreatments', replace
		}

		use `tcpre`pre'post`post'', clear
		gen byte prewindow = `pre'
		gen byte postwindow = `post'
		keep stateabb statefipsnum date prewindow postwindow post treatmentid treated control mw mwtreatment numdonors
		if `counter' == 1 save `alltreatmentsandcontrols', replace
		else {
			append using `alltreatmentsandcontrols'
			save `alltreatmentsandcontrols', replace
		}
	} // post
} // pre 



* now limit events to those that satisfy certain requirements
use `alltreatmentsandcontrols', clear

* drop states that do not exist throughout the entire pre-/post-treatment period
egen count = count(date), by(prewindow postwindow treatmentid statefipsnum)
gen missing = count ~= prewindow + postwindow
drop if missing == 1
drop count missing

* drop treatments where treated state no longer exists
egen treatexist = max(treated), by(prewindow postwindow treatmentid)
drop if treatexist == 0
drop treatexist

* recount donors and enforce minimal donor requirement
drop numdonors
egen _numdonors = count(statefipsnum) if control == 1, by(prewindow postwindow treatmentid date)
egen numdonors = max(_numdonors), by(prewindow postwindow treatmentid)
drop _numdonors
keep if numdonors >= 4 & numdonors ~= .

* enforce the size of minimum wage increase
egen maxmwtreatment = max(mwtreatment), by(prewindow postwindow treatmentid)
egen minmwtreatment = min(mwtreatment), by(prewindow postwindow treatmentid)
gen pctmwchange = maxmwtreatment/minmwtreatment - 1
keep if pctmwchange >= 0.05

save `alltreatmentsandcontrols', replace

* filter the treatments to satisfy these requirements
egen tag = tag(prewindow postwindow treatmentid)
keep if tag == 1
keep prewindow postwindow treatmentid maxmwtreatment minmwtreatment pctmwchange numdonors
merge 1:1 prewindow postwindow treatmentid using `alltreatments', keep(3) nogenerate

* now select maximal window for each stateXdate treatment in the following way:
* first, prioritize pre-treatment period
egen byte maxpre = max(prewindow), by(stateabb date)
keep if prewindow == maxpre
* second, choose maximal post-treatment period
egen byte maxpost = max(postwindow), by(stateabb date)
keep if postwindow == maxpost
drop maxpre maxpost
rename treatmentid oldtreatmentid
egen treatmentid = group(stateabb date)
sort treatmentid
save ${cleandata}treatments_prelength99_postlength99.dta, replace

* filter the treatment + controls dataset to only include these maximal window treatments
use `alltreatmentsandcontrols', clear
rename treatmentid oldtreatmentid
merge m:1 prewindow postwindow oldtreatmentid using ${cleandata}treatments_prelength99_postlength99.dta, keep(3) nogenerate keepusing(treatmentid)
sort treatmentid treated stateabb date
drop oldtreatmentid
save ${cleandata}treatmentsandcontrols_prelength99_postlength99.dta, replace

use ${cleandata}treatments_prelength99_postlength99.dta, clear
drop oldtreatmentid
save ${cleandata}treatments_prelength99_postlength99.dta, replace

* drop all events with less than 5 donors
* in practice this seems to be one event
* drop these events and create "final" dataset of treatments
use ${cleandata}treatments_prelength99_postlength99.dta, clear
drop if numdonors < 5
save ${cleandata}finaltreatments_prelength99_postlength99.dta, replace 

keep treatmentid
merge 1:m treatmentid using ${cleandata}treatmentsandcontrols_prelength99_postlength99.dta, keep(3) nogenerate
save ${cleandata}finaltreatmentsandcontrols_prelength99_postlength99.dta, replace
