* Calculate significance cutoffs for rank-based estimates
capture program drop pranksigcutoffs
program define pranksigcutoffs
clear


* SET SEED
set seed 52537784


* Generate blank dataset
set obs $sigsamplesize
local numevents = 35

* Generate random uniforms
qui forvalues event = 1 / `numevents' {
	g u`event' = runiform()
}
local ulist ""
* Create mean across events, then percentiles
forvalues event = 1 / `numevents' {
	di "Working on `event' of `numevents'"
	local ulist `ulist' u`event'
	egen meanu_`event' = rowmean(`ulist')
	_pctile meanu_`event', percentiles(0.5 2.5 5 90 95 97.5 99.5)

	if `event' == 1 mat results = [`event',r(r1),r(r2),r(r3),r(r4),r(r5),r(r6),r(r7)]
	else mat results = results \ [`event',r(r1),r(r2),r(r3),r(r4),r(r5),r(r6),r(r7)]
	drop meanu_`event'
}
mat colnames results = numevents cut0_5 cut2_5 cut5 cut90 cut95 cut97_5 cut99_5
clear
svmat results, names(col)
save ${tabledata}pranksigcutoffs.dta, replace



* COMPARE RESULTS TO USING WEIBULL-PERCENTILE RANKS WITH APPROPRIATE NUMBER OF DONORS
use ${tabledata}pranksigcutoffs.dta, clear
local numevents = 29
use if numevents == `numevents' using ${tabledata}pranksigcutoffs, clear
foreach level in 0_5 2_5 5 95 97_5 99_5 {
	local uniformcut`level': di cut`level'
}
use ${cleandata}finaltreatments_prelength99_postlength99, clear
egen event = group(treatmentid)
sum event
assert r(max) == `numevents'
forvalues event = 1/29 {
	sum numdonors if event == `event'
	local statecount`event' = r(mean) + 1
}
clear
set obs $sigsamplesize
qui forvalues event = 1 / `numevents' {
	gen rank`event' = floor((`statecount`event''- 1 + 1)*runiform() + 1)
	* use Weibull rule: rank / (num + 1) 
	gen prank`event' = rank`event' / (`statecount`event'' + 1)
}
egen meanpctrank = rowmean(prank*)
keep meanpctrank

_pctile meanpctrank, percentiles(0.5 2.5 5.0 95.0 97.5 99.5)
gen cut0_5 = r(r1)
gen cut2_5 = r(r2)
gen cut5 = r(r3)
gen cut95 = r(r4)
gen cut97_5 = r(r5)
gen cut99_5 = r(r6)

* calculate rejection rates instead using iid critical values
sum meanpctrank if meanpctrank < `uniformcut0_5' | meanpctrank > `uniformcut99_5'
gen rejrate1_0 = r(N) / _N
sum meanpctrank if meanpctrank < `uniformcut2_5' | meanpctrank > `uniformcut97_5'
gen rejrate5_0 = r(N) / _N
sum meanpctrank if meanpctrank < `uniformcut5' | meanpctrank > `uniformcut95'
gen rejrate10_0 = r(N) / _N
gen iterations = _N

keep in 1
keep *cut* rejrate* iterations
noi list rejrate* iterations, ab(30)
save ${tabledata}discreteranks_cutoffs.dta, replace




* Using Irwin-Hall formula, check our simulation:
* set the following two parameters to check the values from the table
local n = 29
local meancritvalue = 0.3949606

local critvalue = `n' * `meancritvalue'
local floor = floor(`critvalue')

local sum = (`critvalue')^`n'

if `floor' >= 1 forvalues k = 1 / `floor' {
	local sum = `sum' + (-1)^`k' * comb(`n',`k') * (`critvalue' - `k')^(`n')
}

local solution = 1/(exp(lnfactorial(`n'))) * `sum'

di %6.5f `solution'*100 "th percentile"


end


pranksigcutoffs


