local tablelist treatmentlist winconfig donorrmspe donorweights eventelast mainresults msperatio windowlength allmodels rejrates unicritvalues
set linesize 200

* create concordance between original spec numbers and table spec numbers
* see results_batchjob.do to get this right
clear
set obs 7
gen origspec = _n
gen tablespec = .
replace tablespec = 1 if origspec == 1 /* Quarterly */
replace tablespec = 2 if origspec == 5 /* Ann */
replace tablespec = 3 if origspec == 6 /* Both Ann */
replace tablespec = 4 if origspec == 3 /* Both Ann + DLM + Ind */
drop if tablespec == .

gen spec_quarterly = 0
gen spec_ann = 0
gen spec_bothann = 0
gen spec_dlmind = 0
replace spec_quarterly = 1 if tablespec == 1
replace spec_ann = 1 if tablespec == 2 | tablespec == 3 | tablespec == 4 | tablespec == 6
replace spec_bothann = 1 if tablespec == 3 | tablespec == 4
replace spec_dlmind = 1 if tablespec == 3
save ${tabledata}synthspecconcordance.dta, replace

*************************************
*** STATS BY WINDOW CONFIGURATION ***
*************************************
capture program drop table_treatmentlist
program define table_treatmentlist

use ${cleandata}finaltreatments_prelength99_postlength99, clear

rename prewindow prewin
rename postwindow postwin
rename pctmwchange pctmw
rename date treatdate
egen event = group(treatmentid)
sum event
local eventmax = r(max)

forvalues event = 1/`eventmax' {
	preserve
	keep if event == `event'
	assert _n == 1
	foreach stat in prewin postwin numdonors {
		local `stat'`event' : di `stat'
	}
	local pctmw`event' : di %04.3f pctmw
	local state`event': di stateabb
	local date`event': di %tq treatdate
	restore
}

use ${cleandata}finaltreatmentsandcontrols_prelength99_postlength99, clear
keep if treated == 1
egen event = group(treatmentid)
gen int intmw = round(mw * 100)
tsset event date
tsspell intmw
egen mwchanges = max(_spell), by(event)
replace mwchanges = mwchanges - 1
egen tag = tag(event)
keep if tag == 1
forvalues event = 1/`eventmax' {
	preserve
	keep if event == `event'
	assert _n == 1
	local mwchanges`event' : di mwchanges
	restore
}

* default column
local df S[table-column-width=15mm,table-parse-only]

capture log close
capture log using ${tables}table_treatmentlist.tex, text replace
di "\begin{tabular}{"
di "c"
di "c"
di "`df'"
di "`df'"
di "S[table-column-width=25mm,table-parse-only]"
di "`df'"
di "`df'"
di "}"
di "\toprule"
di "& & \multicolumn{2}{c}{Window length} & & \multicolumn{2}{c}{MW increases} \\"
di "\cmidrule(lr){3-4} \cmidrule(lr){6-7}"
di "\multicolumn{2}{c}{Event} & \multicolumn{1}{c}{Pre} & \multicolumn{1}{c}{Post} & \multicolumn{1}{c}{Donors} & \multicolumn{1}{c}{Number} & \multicolumn{1}{c}{Percent} \\"
di "\cmidrule{1-7}"
forvalues event = 1/ `eventmax' {
	di "`state`event'' & `date`event'' & `prewin`event'' & `postwin`event'' & `numdonors`event'' & `mwchanges`event'' & `pctmw`event'' \\"
}
di "\bottomrule"
di "\end{tabular}"
capture log close



end




capture program drop table_winconfig
program define table_winconfig

use ${cleandata}finaltreatments_prelength99_postlength99, clear

local pre1 = 8
local pre2 = 16
local pre3 = 24
local pre4 = 32

local post1 = 4
local post2 = 8
local post3 = 12

local premax = 4
local postmax = 3

forvalues pre = 1 / `premax' {
	forvalues post = 1 / `postmax' {
		use ${cleandata}finaltreatments_prelength99_postlength99, clear
		keep if prewindow >= `pre`pre'' & postwindow >= `post`post''
		tab stateabb, nofreq
		local numtrstpre`pre'post`post' = r(r)
		tab treatmentid, nofreq
		local numtrevpre`pre'post`post' = r(r)
		sum numdonors
		local minnumdpre`pre'post`post' = r(min)
		local maxnumdpre`pre'post`post' = r(max)
		local meannumdpre`pre'post`post': di %3.1f r(mean)
		sum pctmwchange
		local minpctmwpre`pre'post`post': di %4.3f r(min)
		local maxpctmwpre`pre'post`post': di %4.3f r(max)
		local meanpctmwpre`pre'post`post': di %4.3f r(mean)
	}
}

* default column
local df c

capture log close
capture log using ${tables}table_winconfig.tex, text replace
di "\begin{tabular}{"
di "S[table-column-width=10mm,table-parse-only]"
di "S[table-column-width=10mm,table-parse-only]"
di "`df'"
di "`df'"
di "`df'"
di "`df'"
di "`df'"
di "`df'"
di "`df'"
di "`df'"
di "}"
di "\toprule"
di "\multicolumn{2}{c}{Minimum Window} & & & \multicolumn{3}{c}{Number of donors} & \multicolumn{3}{c}{Percent MW change} \\"
di "\cmidrule(lr){1-2} \cmidrule(lr){5-7} \cmidrule(lr){8-10}"
di "\multicolumn{1}{c}{Pre-} & \multicolumn{1}{c}{Post-} & \multicolumn{1}{c}{Events} & \multicolumn{1}{c}{Treated states} &"
di "\multicolumn{1}{c}{Min.} & \multicolumn{1}{c}{Mean} & \multicolumn{1}{c}{Max.} & \multicolumn{1}{c}{Min.} & \multicolumn{1}{c}{Mean} & \multicolumn{1}{c}{Max.} \\"
di "\cmidrule{1-10}"
forvalues pre = 1 / `premax' {
	forvalues post = 1 / `postmax' {
		if `pre' == 4 & (`post' == 2 | `post' == 3) di ""
		else if `pre' == 3 & `post' == 3 di ""
		else di "`pre`pre'' & `post`post'' & `numtrevpre`pre'post`post'' & `numtrstpre`pre'post`post'' & `minnumdpre`pre'post`post'' & `meannumdpre`pre'post`post'' & `maxnumdpre`pre'post`post'' & `minpctmwpre`pre'post`post'' & `meanpctmwpre`pre'post`post'' & `maxpctmwpre`pre'post`post'' \\"
	}
}
di "\bottomrule"
di "\end{tabular}"
capture log close


end





capture program drop table_donorrmspe
program define table_donorrmspe

use ${tabledata}placeboresults_summary.dta, clear
collapse (mean) premspe postmspe, by(outcome synthnumber)
rename synthnumber origspec
merge m:1 origspec using ${tabledata}synthspecconcordance.dta, keep(3) nogenerate
keep if tablespec >= 1 & tablespec <= 4

gen prermspe = sqrt(premspe)
gen postrmspe = sqrt(postmspe)
drop premspe postmspe
sort outcome tablespec

foreach out in erate wage {
	forvalues model = 1/4 {
		preserve
		keep if outcome == "`out'" & tablespec == `model'
		foreach postpre in post pre {
			sum `postpre'rmspe
			local `out'`postpre'rmspe`model': di %05.4f r(mean) 
		}
		restore
	}
}
local posttitle "Post-treatment"
local pretitle "Pre-treatment"
local eratetitle "Employment"
local wagetitle "Wage"

local df S[table-column-width=25mm,table-number-alignment=center]

capture log close
capture log using ${tables}table_donorrmspe.tex, text replace
di "\sisetup{table-figures-integer=1,table-figures-decimal=4}"
di "\begin{tabular}{"
di "l"
di "`df'"
di "`df'"
di "`df'"
di "`df'"
di "}"
di "\toprule"

di "& \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} & \multicolumn{1}{c}{(3)} & \multicolumn{1}{c}{(4)} \\"
foreach out in erate wage {
	di "& \multicolumn{4}{c}{\emph{``out'title'}}\\"
	foreach postpre in pre post {
		di "``postpre'title' & ``out'`postpre'rmspe1' & ``out'`postpre'rmspe2' & ``out'`postpre'rmspe3' & ``out'`postpre'rmspe4' \\"
	}
	di "\\"
}

di "\\"
di "\emph{Predictors} \\"
di "Quarterly outcomes		& \multicolumn{1}{c}{Y} &          &          &          \\"
di "Annualized outcomes		&          & \multicolumn{1}{c}{Y} & \multicolumn{1}{c}{Y} & \multicolumn{1}{c}{Y} \\"
di "Both annualized outcomes	&          &          & \multicolumn{1}{c}{Y} & \multicolumn{1}{c}{Y} \\"
di "Industry \& Other controls &          &          &          & \multicolumn{1}{c}{Y} \\"

di "\bottomrule"
di "\end{tabular}"

capture log close

end



capture program drop table_donorweights
program define table_donorweights

use ${tabledata}weight_summary.dta, clear
keep if synthnumber == ${prefproc}
rename weights donorweight
assert donordistance ~= .
gen same0_500 = donordistance <= 500
gen same0_1000 = donordistance <= 1000
gen sameregion = donorregion == treatedregion
gen samedivision = donordivision == treateddivision

foreach dist in 0_500 0_1000 region division {
	egen tin`dist'donors = total(same`dist'), by(outcome)
	egen tin`dist'weight = total(donorweight*same`dist'), by(outcome)
	egen tout`dist'donors = total((1-same`dist')), by(outcome)
	egen tout`dist'weight = total(donorweight*(1-same`dist')), by(outcome)
	* inside and outside per donor weight
	gen inpdw`dist' = tin`dist'weight / tin`dist'donors
	gen outpdw`dist' = tout`dist'weight / tout`dist'donors
	* inside/outside relative weight
	gen relw`dist' = inpdw`dist' / outpdw`dist'
}

foreach out in erate wage {
	preserve
	keep if outcome == "`out'"
	foreach dist in 0_500 0_1000 region division {
		foreach stat in inpdw outpdw relw {
			local `out'`stat'`dist': di %04.3f `stat'`dist'
		}
	}
	restore
}
local eratetitle "Employment"
local wagetitle "Wage"
local title0_500 "Within 0 - 500 miles"
local title0_1000 "Within 0 - 1000 miles"
local titleregion "Same region"
local titledivision "Same division"

local df S[table-column-width=25mm,table-number-alignment=center]

capture log close
capture log using ${tables}table_donordistance.tex, text replace
di "\sisetup{table-figures-integer=1,table-figures-decimal=3}"
di "\begin{tabular}{"
di "l"
di "`df'"
di "`df'"
di "`df'"
di "}"
di "\toprule"
di "& \multicolumn{2}{c}{Weights per donor} \\"
di "\cmidrule(l{2em}r{2em}){2-3}"
di "Donor relation to treatment & \multicolumn{1}{c}{Inside} & \multicolumn{1}{c}{Outside} & \multicolumn{1}{c}{Relative weight}\\"
di "\cmidrule{1-4}"
foreach out in erate wage {
	di "& \multicolumn{3}{c}{\emph{``out'title'}} \\"
	foreach dist in region division 0_500 0_1000 {
		di "`title`dist'' &"
		di "``out'inpdw`dist'' &"
		di "``out'outpdw`dist'' &"
		di "``out'relw`dist'' \\"
	}
	if "`out'" == "erate" di "\\"
}
di "\bottomrule"
di "\end{tabular}"
capture log close


end


capture program drop table_eventelast
program define table_eventelast


foreach out in erate wage {

	use stateabb date treatmentid using ${cleandata}finaltreatments_prelength99_postlength99, clear
	rename stateabb trstateabb
	rename date trdate
	rename treatmentid event
	merge 1:1 event using ${tabledata}synth${prefproc}`out'statistics_allopt_byeventci.dta, assert(3) nogenerate
	rename event treatmentid
	egen event = group(treatmentid)
	sum event
	local eventmax = r(max)
	forvalues event = 1 / `eventmax' {
		preserve
		keep if event == `event'
		assert _n == 1
		foreach stat in postelast {
			sum `stat'
			local `out'`event'`stat' : di %04.3f r(mean)
			local stars ""
			sum `stat'prank
			local value = r(mean)
			if `value' > 0.95 & `value' ~= . local stars "*"
			if `value' < 0.05 local stars "*"
			local `out'`event'`stat'pr: di %04.3f `value' "`stars'"
			local `out'`event'`stat'ci : di  "(\hspace{0.5em}" "\$" %04.3f `stat'loci90 "\$" ",\hspace{0.5em}"  "\$" %04.3f `stat'hici90 "\$" ")" 
		}
		local state`event': di trstateabb
		local date`event': di %tq trdate
		restore
	}
}

local df S[table-column-width=15mm,table-number-alignment=center]

capture log close
capture log using ${tables}table_eventelast.tex, text replace
di "\sisetup{table-figures-integer=1,table-figures-decimal=3}"
di "\begin{tabular}{"
di "c"
di "c"
di "c"
di "`df'"
di "`df'"
di "c"
di "c"
di "`df'"
di "`df'"
di "c"
di "}"
di "\toprule"
di "& & & \multicolumn{3}{c}{Employment} & & \multicolumn{3}{c}{Wages} \\"
di "\cmidrule(lr){4-6} \cmidrule(lr){8-10}"
di "\multicolumn{2}{c}{Event} & &"
di "\multicolumn{1}{c}{Elasticity} & \multicolumn{1}{c}{Rank} & \multicolumn{1}{c}{90\% CI} & &"
di "\multicolumn{1}{c}{Elasticity} & \multicolumn{1}{c}{Rank} & \multicolumn{1}{c}{90\% CI} \\"
di "\cmidrule{1-10}"
forvalues event = 1/ `eventmax' {
	di "`state`event'' & `date`event'' & & `erate`event'postelast' & `erate`event'postelastpr' & `erate`event'postelastci' & & `wage`event'postelast' & `wage`event'postelastpr' & `wage`event'postelastci' \\"
}
di "\bottomrule"
di "\end{tabular}"
capture log close
end


capture program drop table_mainresults
program define table_mainresults

use ${cleandata}finaltreatments_prelength99_postlength99, clear
tab treatmentid, nofreq
local numevents = r(r)
foreach out in erate wage {
	use group preconfig postconfig postelastmedian using ${aggresults}synth${prefproc}`out'statistics_allopt_ranked_aggregated.dta, clear
	merge 1:1 group preconfig postconfig using ${tabledata}synth${prefproc}`out'statistics_allopt_aggregatedci.dta, assert(3) nogenerate
	assert _n == 1
	gen numevents = `numevents'
	merge 1:m numevents using ${tabledata}pranksigcutoffs.dta, keep(3) nogenerate
	gen sig1 = postelastprankmean < cut0_5 | postelastprankmean > cut99_5
	gen sig5 = postelastprankmean < cut2_5 | postelastprankmean > cut97_5
	gen sig10 = postelastprankmean < cut5 | postelastprankmean > cut95
	local `out'postelastmean: di %04.3f postelastmean 
	local `out'postelastmed: di %04.3f postelastmedian
	local `out'postelastHL: di %04.3f postelastmeanHL
	local stars ""
	if sig10 == 1 local stars "*"
	if sig5 == 1 local stars "**"
	if sig1 == 1 local stars "***"
	local `out'postelastpr: di %04.3f postelastprankmean "`stars'"
	local `out'postelastci : di  "(\hspace{0.5em}" "\$" %04.3f postelastmeanloci95 "\$" ",\hspace{0.5em}"  "\$" %04.3f postelastmeanhici95 "\$" ")" 
}
local eratetitle "Employment"
local wagetitle "Wages"


local df S[table-column-width=25mm,table-number-alignment=center]

capture log close
capture log using ${tables}table_mainresults.tex, text replace
di "\sisetup{table-figures-integer=1,table-figures-decimal=3}"
di "\begin{tabular}{"
di "c"
di "`df'"
di "`df'"
di "`df'"
di "`df'"
di "c"
di "}"
di "\toprule"
di " & & & & \multicolumn{2}{c}{Hodges-Lehmann} \\"
di "\cmidrule{5-6}"
di "& \multicolumn{1}{c}{Median elasticity} & \multicolumn{1}{c}{Mean elasticity} & \multicolumn{1}{c}{Mean rank} & \multicolumn{1}{c}{Elasticity} & \multicolumn{1}{c}{95\% CI} \\"
di "\cmidrule{1-6}"

foreach out in erate wage {
	di "``out'title' & ``out'postelastmed' & ``out'postelastmean' & ``out'postelastpr' & ``out'postelastHL'  & ``out'postelastci'  \\"

}

di "\bottomrule"
di "\end{tabular}"

capture log close
end


capture program drop table_msperatio
program define table_msperatio
use ${tabledata}premsperatio_donortrimmed.dta, clear

drop id
recode donormsperatio (.=999999)
gen negsort = -donormsperatio
egen id = group(negsort)
sum id
local idmax = r(max)
recode donormsperatio (999999=.)

foreach out in erate wage {
	forvalues i = 1 / `idmax' {
		preserve
		keep if outcome == "`out'" & id == `i'
		assert _n == 1

		gen numevents = 32
		merge 1:1 numevents using ${tabledata}pranksigcutoffs.dta, keep(3) nogenerate
		gen sig1 = postelastprankmean < cut0_5 | postelastprankmean > cut99_5
		gen sig5 = postelastprankmean < cut2_5 | postelastprankmean > cut97_5
		gen sig10 = postelastprankmean < cut5 | postelastprankmean > cut95
		local `out'`i'postelastmean: di %04.3f postelastmean 
		local `out'`i'kurtosis: di %4.3f kurtosis
		local `out'`i'sd: di %4.3f sd
		local `out'`i'min: di %4.3f minpostelast
		local `out'`i'max: di %4.3f maxpostelast
		local `out'`i'numdonors: di numdonors
		local `out'`i'fracdonors: di %4.3f fracdonors
		local `out'`i'ratio: di donormsperatio
		local stars ""
		if sig10 == 1 local stars "*"
		if sig5 == 1 local stars "**"
		if sig1 == 1 local stars "***"
		local `out'`i'postelastpr: di %04.3f postelastprankmean "`stars'"
		local `out'`i'postelastci : di  "(\hspace{0.5em}" "\$" %04.3f postelastmeanloci95 "\$" ",\hspace{0.5em}"  "\$" %04.3f postelastmeanhici95 "\$" ")" 
		restore
	}
}

local eratetitle "Employment"
local wagetitle "Wages"
local df S[table-number-alignment=center]

capture log close
capture log using ${tables}table_msperatio.tex, text replace
di "\sisetup{table-figures-integer=1,table-figures-decimal=3}"
di "\begin{tabular}{"
di "c"
di "c"
di "`df'"
di "`df'"
di "`df'"
di "`df'"
di "`df'"
di "`df'"
di "c"
di "}"
di "\toprule"
di " & \multicolumn{2}{c}{Donor states} & \multicolumn{4}{c}{Donor state elasticities} & \multicolumn{2}{c}{Treated state elasticities} \\"
di "\cmidrule(lr){2-3} \cmidrule(lr){4-7} \cmidrule(lr){8-9}"
di "\multicolumn{1}{c}{MSPE Ratio} & "
di "\multicolumn{1}{c}{Number} & \multicolumn{1}{c}{Fraction} &"
di "\multicolumn{1}{c}{Min} & \multicolumn{1}{c}{Max} & \multicolumn{1}{c}{SD} & \multicolumn{1}{c}{Kurtosis} &"
di "\multicolumn{1}{c}{Mean rank} & \multicolumn{1}{c}{95\% CI} \\"
di "\cmidrule{1-9}"
foreach out in erate wage {
		di "\multicolumn{9}{c}{\emph{``out'title'}} \\"
	forvalues i = 1 / `idmax' {
		di "``out'`i'ratio' & ``out'`i'numdonors' & ``out'`i'fracdonors' & ``out'`i'min'  & ``out'`i'max' & ``out'`i'sd'  & ``out'`i'kurtosis' & ``out'`i'postelastpr' & ``out'`i'postelastci' \\"
	}
	if "`out'" == "erate" di "\\"
}

di "\bottomrule"
di "\end{tabular}"

capture log close



end




capture program drop table_windowlength
program define table_windowlength
use ${tabledata}examine_windowlength.dta, clear
drop id
recode pre post (. = 0)
egen id = group(pre post)
sum id
local idmax = r(max)
recode pre post (0 = .)

foreach out in erate wage {
	forvalues i = 1 / `idmax' {
		preserve
		keep if outcome == "`out'" & id == `i'
		assert _n == 1

		merge 1:1 numevents using ${tabledata}pranksigcutoffs.dta, keep(3) nogenerate
		gen sig1 = postelastprankmean < cut0_5 | postelastprankmean > cut99_5
		gen sig5 = postelastprankmean < cut2_5 | postelastprankmean > cut97_5
		gen sig10 = postelastprankmean < cut5 | postelastprankmean > cut95
		local `out'`i'postelastmean: di %04.3f postelastmean 
		local `out'`i'postelastHL: di %04.3f postelastHL
		local `out'`i'numevents: di numevents
		local `out'`i'pre: di pre
		local `out'`i'post: di post
		local stars ""
		if sig10 == 1 local stars "*"
		if sig5 == 1 local stars "**"
		if sig1 == 1 local stars "***"
		local `out'`i'postelastpr: di %04.3f postelastprankmean "`stars'"
		local `out'`i'postelastci : di  "(\hspace{0.5em}" "\$" %04.3f postelastmeanloci95 "\$" ",\hspace{0.5em}"  "\$" %04.3f postelastmeanhici95 "\$" ")" 
		restore
	}
}

local eratetitle "Employment"
local wagetitle "Wages"
local df S[table-column-width=25mm,table-number-alignment=center]

capture log close
capture log using ${tables}table_windowlength.tex, text replace
di "\sisetup{table-figures-integer=1,table-figures-decimal=3}"
di "\begin{tabular}{"
di "c"
di "c"
di "c"
di "`df'"
di "`df'"
di "`df'"
di "c"
di "}"
di "\toprule"
di "\multicolumn{2}{c}{Window length} & & & & \multicolumn{2}{c}{Hodges-Lehmann} \\"
di "\cmidrule{1-2} \cmidrule{6-7}"
di "\multicolumn{1}{c}{Pre-} & \multicolumn{1}{c}{Post-} & \multicolumn{1}{c}{Events} & \multicolumn{1}{c}{Mean elasticity} & \multicolumn{1}{c}{Mean rank} & "
di "\multicolumn{1}{c}{Elasticity} & \multicolumn{1}{c}{95\% CI} \\"
di "\cmidrule{1-7}"

foreach out in erate wage {
		di "\multicolumn{7}{c}{\emph{``out'title'}} \\"
	forvalues i = 1 / `idmax' {
		di "``out'`i'pre' & ``out'`i'post' & ``out'`i'numevents' & ``out'`i'postelastmean' & ``out'`i'postelastpr' & ``out'`i'postelastHL'  & ``out'`i'postelastci'  \\"
	}
	if "`out'" == "erate" di "\\"
}

di "\bottomrule"
di "\end{tabular}"

capture log close

end



capture program drop table_allmodels
program define table_allmodels

use ${cleandata}finaltreatments_prelength99_postlength99, clear
tab treatmentid, nofreq
local numevents = r(r)
foreach out in erate wage {
	forvalues i = 1/4 {
		use if tablespec == `i' using ${tabledata}synthspecconcordance.dta, clear
		assert _n == 1
		sum origspec
		local j = r(mean)

		use ${tabledata}synth`j'`out'statistics_allopt_aggregatedci.dta, clear
		assert _n == 1
		gen numevents = 29
		merge 1:m numevents using ${tabledata}pranksigcutoffs.dta, keep(3) nogenerate

		merge 1:m numevents using ${tabledata}pranksigcutoffs.dta, keep(3) nogenerate
		gen sig1 = postelastprankmean < cut0_5 | postelastprankmean > cut99_5
		gen sig5 = postelastprankmean < cut2_5 | postelastprankmean > cut97_5
		gen sig10 = postelastprankmean < cut5 | postelastprankmean > cut95

		local `out'`i'postelastmean: di %04.3f postelastmean 
		local `out'`i'postelastHL: di %04.3f postelastmeanHL
		local stars ""
		if sig10 == 1 local stars "*"
		if sig5 == 1 local stars "**"
		if sig1 == 1 local stars "***"
		local `out'`i'postelastpr: di %04.3f postelastprankmean "`stars'"
		local `out'`i'postelastci : di  "\multicolumn{1}{c}{(\hspace{0.5em}" "\$" %04.3f postelastmeanloci95 "\$" ",\hspace{0.5em}"  "\$" %04.3f postelastmeanhici95 "\$" ")}" 

	}
}

local stat1name postelastmean
local stat2name postelastpr
local stat3name postelastHL
local stat4name postelastci


local eratetitle "Employment"
local wagetitle "Wage"
local stat1title "Mean elasticity"
local stat2title "Mean rank"
local stat3title "HL elasticity"
local stat4title "HL 95\% CI"
local stat5title "Weight correlation"

local df S[table-column-width=25mm,table-number-alignment=center]

capture log close
capture log using ${tables}table_allmodels.tex, text replace
di "\sisetup{table-figures-integer=1,table-figures-decimal=3}"
di "\begin{tabular}{"
di "l"
di "`df'"
di "`df'"
di "`df'"
di "`df'"
di "}"
di "\toprule"

di "& \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} & \multicolumn{1}{c}{(3)} & \multicolumn{1}{c}{(4)} \\"
foreach out in erate wage {
	di "& \multicolumn{4}{c}{\emph{``out'title'}}\\"
	forvalues i = 1/4 {
		di "`stat`i'title' &"
		forvalues j = 1/3 {
			di "``out'`j'`stat`i'name'' &"
		}
		di "``out'4`stat`i'name'' \\"
	}
	di "\\"
}

di "\\"
di "\emph{Predictors} \\"
di "Quarterly outcomes		& \multicolumn{1}{c}{Y} &          &          &          \\"
di "Annualized outcomes		&          & \multicolumn{1}{c}{Y} & \multicolumn{1}{c}{Y} & \multicolumn{1}{c}{Y} \\"
di "Both annualized outcomes	&          &          & \multicolumn{1}{c}{Y} & \multicolumn{1}{c}{Y} \\"
di "Industry \& Other controls &          &          &          & \multicolumn{1}{c}{Y} \\"
di "\bottomrule"
di "\end{tabular}"

capture log close

end








capture program drop table_rejrates
program define table_rejrates

local resolution = 0.0001

use ${tabledata}rinf_results, clear
keep if trim == 0 & outcome == "erate"
assert _n == 1
local rinfempelast: di %4.3f postelastmean
local rinfempci : di  "(\hspace{0.5em}" "\$" %04.3f rinf_postelastmeanlo95 "\$" ",\hspace{0.5em}"  "\$" %04.3f rinf_postelastmeanhi95 "\$" ")" 
local rinfcritval : di  "\multicolumn{1}{c}{-}" 
local rinfrejrate : di  "\multicolumn{1}{c}{-}" 


use ${aggresults}synth${prefproc}eratestatistics_allopt_ranked_byevent, clear
gen id = 1
tempfile input
save `input' 

use ${tabledata}pranksigcutoffs.dta, clear
gen rejrate5_0 = 0.05
tempfile uniformcutoffs
save `uniformcutoffs'

use ${tabledata}discreteranks_cutoffs.dta, clear
gen numevents = 29
tempfile discretecutoffs
save `discretecutoffs'

use ${tabledata}rank_dependence_cutoffs1.dta, clear
gen numevents = 29
tempfile overlapcutoffs
save `overlapcutoffs'

foreach out in uniform discrete overlap {
	tempfile output outputHL
	invertstats, inputdata(`input') outputaggregate(`output') aggcutoffs(``out'cutoffs') statlist(postelast) aggstatlist(mean) increment(`resolution') id(id) cilev(95)
	use `output', clear
	local `out'empci : di  "(\hspace{0.5em}" "\$" %04.3f postelastmeanloci95 "\$" ",\hspace{0.5em}"  "\$" %04.3f postelastmeanhici95 "\$" ")" 
	invertstats, inputdata(`input') outputaggregate(`outputHL') aggcutoffs(``out'cutoffs') statlist(postelast) aggstatlist(mean) increment(`resolution') id(id) cilev(95) hodgeslehmann
	use `outputHL', clear
	egen postelastHL = rowmean(postelastmeanloci95 postelastmeanhici95)
	local `out'empelast: di %4.3f postelastHL
	use ``out'cutoffs', clear
	keep if numevents == 29
	assert _n == 1
	local `out'critval : di  "(" "\$" %04.3f cut2_5 "\$" ",\hspace{0.5em}"  "\$" %04.3f cut97_5 "\$" ")"

	local `out'rejrate : di %4.3f rejrate5_0 
}

local uniformtitle "Method 1: Rank, uniform iid."
local discretetitle "Method 2: Rank, discrete iid."
local overlaptitle "Method 3: Rank, rand. inference"
local rinftitle "Method 4: Elasticity, rand. inference"

local uniformesttype "Hodges-Lehmann"
local discreteesttype "Hodges-Lehmann"
local overlapesttype "Hodges-Lehmann"
local rinfesttype "Mean"

local df S[table-number-alignment=center]

capture log close
capture log using ${tables}table_rejrates.tex, text replace
di "\sisetup{table-figures-integer=1,table-figures-decimal=3}"
di "\begin{tabular}{"
di "l"
di "c"
di "`df'"
di "c"
di "`df'"
di "c"

di "}"
di "\toprule"
di " & \multicolumn{2}{c}{Rank-based inference} & \multicolumn{3}{c}{Aggregated employment elasticity} \\"
di "\cmidrule(lr){2-3} \cmidrule(lr){4-6}"
di "& \multicolumn{1}{c}{95\% crit. values} & \multicolumn{1}{c}{5\% rej. rate} & "
di "\multicolumn{1}{c}{Type} & \multicolumn{1}{c}{Point estimate} & \multicolumn{1}{c}{95\% CI} \\"
di "\cmidrule{1-6}"
foreach out in uniform discrete overlap rinf {
	*if "`out'" == "rinf" di "\\"
	di "``out'title' & ``out'critval' & ``out'rejrate' & ``out'esttype'  & ``out'empelast' & ``out'empci' \\"
}

di "\bottomrule"
di "\end{tabular}"

capture log close


end




capture program drop table_unicritvalues
program define table_unicritvalues

forvalues i = 1/30 {
	use if numevents ==`i' using ${tabledata}pranksigcutoffs, clear
	foreach cutpoint in 0_5 2_5 5 90 95 97_5 99_5 {
		local N`i'cut`cutpoint' : di %04.3f cut`cutpoint'
	}
}

local df S[table-column-width=15mm,table-number-alignment=center]

capture log close
capture log using ${tables}table_unicritvalues.tex, text replace
di "\sisetup{table-figures-integer=1,table-figures-decimal=3}"
di "\begin{tabular}{"
di "S[table-column-width=15mm,table-number-alignment=center,table-figures-integer=2,table-figures-decimal=0]"
di "`df'"
di "`df'"
di "`df'"
di "`df'"
di "`df'"
di "`df'"
di "}"
di "\toprule"
di "& \multicolumn{6}{c}{Percentile} \\"
di "\cmidrule{2-7}"
di "\multicolumn{1}{c}{N} & \multicolumn{1}{c}{0.5} & \multicolumn{1}{c}{2.5} & \multicolumn{1}{c}{5.0} & \multicolumn{1}{c}{95.0} & \multicolumn{1}{c}{97.5} & \multicolumn{1}{c}{99.5} \\"
di "\cmidrule{1-7}"
forvalues i = 1/30 {
	di "`i' & `N`i'cut0_5' & `N`i'cut2_5' & `N`i'cut5' & `N`i'cut95' & `N`i'cut97_5' & `N`i'cut99_5' \\"
}

di "\bottomrule"
di "\end{tabular}"
capture log close


end





foreach table in `tablelist' {
	table_`table'
}
