
* this program inverts test statistics 
* it will be called later 
* it generates `cilev' CIs for all `id' groups
* and for given a given statlist `aggstatlist'

capture program drop invertstats
program define invertstats
syntax, inputdata(string) statlist(string) increment(real) id(string) [cilev(real 90) outputevent(string) outputaggregate(string) aggstatlist(string) aggcutoffs(string) hodgeslehmann]
use `inputdata', clear

if "`outputevent'" == "" & "`outputaggregate'" == "" {
	noi di "must select either outputevent dataset or outputaggregate dataset or both"
	exit
}
if "`outputaggregate'" ~= "" & "`aggstatlist'" == "" {
	noi di "if selecting outputaggregate, must also select aggregate stats"
	exit
}

* identify preconfig/postconfig/demogroup combinations
egen idgroup = group(`id')
sum idgroup
local idgroupmax = r(max)

* calculate number of treatment events; needed to identify critical values
egen _numtrevents = count(event) if treated == 1, by(idgroup)
egen numtrevents = max(_numtrevents), by(idgroup)
drop _numtrevents

* create a concordance between idgroup and identifiers
preserve
egen tag = tag(idgroup)
keep if tag == 1
keep `id' idgroup
tempfile idgroupconcordance
save `idgroupconcordance'
restore

* save the data being used
tempfile basedata
save `basedata'

* the code doesn't really work for general CI levels
assert `cilev' == 90 | `cilev' == 95

local cilocut = (100 - `cilev') / 200
local cihicut = (100 + `cilev') / 200
* minimum states needed for individual event CI
local minstates = floor(1/`cilocut' + 1)

* iterate over statistics of interest
qui foreach statistic in `statlist' {
	

	if "`outputevent'" ~= "" {
		* CALCULATE INDIVIDUAL EVENT CIs
		forvalues idgroup = 1 / `idgroupmax' {
			use if idgroup == `idgroup' using `basedata', clear

			* define confidence interval cut points
			gen locut = `cilocut'
			gen hicut = `cihicut'

			if "`hodgeslehmann'" ~= "" {
				replace locut = 0.5
				replace hicut = 0.5
			}

			gen _origbyevent = `statistic' if placebo == 0
			egen origbyevent = max(_origbyevent), by(event)

			levelsof event, local(eventlevels)
			foreach event of numlist `eventlevels' {
				preserve
				keep if event == `event'
				qui sum `statistic' if placebo == 0, d
				local orig = r(mean)
				qui sum `statistic'prank if placebo == 0, d
				local origprank = r(mean)

				* generate search variable
				gen search = `statistic'

				local k_lo = .
				local k_hi = .
				local k = 0

				* this procedure only makes sense if there are enough donors
				sum statecount
				if r(mean) >= `minstates' {
					* three cases
					* CASE I: original percentile rank is below low cutoff
					if `origprank' < locut {
					while `k_lo' == . {
						*noi di _n(1) "running `statistic' idgroup = `idgroup', event = `event', k = `k'"
						* search for cutoffs by shifting treated estimate by k
						* and then recalculate treated percentile rank
						replace search = `statistic' - `k' if placebo == 0
						egen `statistic'newrank = rank(search)
						gen `statistic'newprank = `statistic'newrank/(statecount + 1)
						qui sum `statistic'newprank if placebo == 0, d
						local newprank : di %05.4f r(mean)

						* if above low cutoff, stop and move onto k_hi
						if `newprank' >= locut local k_lo = `k'
						* otherwise subtract increment and proceed
						if `newprank' < locut local k = `k' - `increment'

						drop `statistic'newrank `statistic'newprank
						di "k_lo = `k_lo'"
						di "k_hi = `k_hi'"
						di "newprank = `newprank'"
						di "locut = " locut	
						di "hicut = " hicut
						di "origprank = `origprank'"
					}
					while `k_hi' == . {
						*noi di _n(1) "running `statistic' idgroup = `idgroup', event = `event', k = `k'"
						* search for cutoffs by shifting treated estimate by k
						* and then recalculate treated percentile rank
						replace search = `statistic' - `k' if placebo == 0
						egen `statistic'newrank = rank(search)
						gen `statistic'newprank = `statistic'newrank/(statecount + 1)
						qui sum `statistic'newprank if placebo == 0, d
						local newprank : di %05.4f r(mean)

						* if above above cutoff, stop and complete
						if `newprank' > hicut local k_hi = `k'
						* otherwise subtract increment and proceed
						if `newprank' <= hicut local k = `k' - `increment'

						drop `statistic'newrank `statistic'newprank
						di "k_lo = `k_lo'"
						di "k_hi = `k_hi'"
						di "newprank = `newprank'"
						di "locut = " locut	
						di "hicut = " hicut
						di "origprank = `origprank'"
					}
					} // end case I
			

					* CASE II
					if `origprank' >= locut & `origprank' <= hicut {
					while `k_lo' == . {
						*noi di _n(1) "running `statistic' idgroup = `idgroup', event = `event', k = `k'"
						* search for cutoffs by shifting treated estimate by k
						* and then recalculate treated percentile rank
						replace search = `statistic' - `k' if placebo == 0
						egen `statistic'newrank = rank(search)
						gen `statistic'newprank = `statistic'newrank/(statecount + 1)
						qui sum `statistic'newprank if placebo == 0, d
						local newprank : di %05.4f r(mean)

						* if above low cutoff, stop and move onto k_hi
						if `newprank' < locut local k_lo = `k'
						* otherwise subtract increment and proceed
						if `newprank' >= locut local k = `k' + `increment'

						drop `statistic'newrank `statistic'newprank
						di "k_lo = `k_lo'"
						di "k_hi = `k_hi'"
						di "newprank = `newprank'"
						di "locut = " locut	
						di "hicut = " hicut
						di "origprank = `origprank'"
					}

					* reset k = 0
					local k = 0
					while `k_hi' == . {
						*noi di _n(1) "running `statistic' idgroup = `idgroup', event = `event', k = `k'"
						* search for cutoffs by shifting treated estimate by k
						* and then recalculate treated percentile rank
						replace search = `statistic' - `k' if placebo == 0
						egen `statistic'newrank = rank(search)
						gen `statistic'newprank = `statistic'newrank/(statecount + 1)
						qui sum `statistic'newprank if placebo == 0, d
						local newprank : di %05.4f r(mean)

						* if above above cutoff, stop and complete
						if `newprank' > hicut local k_hi = `k'
						* otherwise subtract increment and proceed
						if `newprank' <= hicut local k = `k' - `increment'

						drop `statistic'newrank `statistic'newprank
						di "k_lo = `k_lo'"
						di "k_hi = `k_hi'"
						di "newprank = `newprank'"
						di "locut = " locut	
						di "hicut = " hicut
						di "origprank = `origprank'"
					}
					} // end case II

					* CASE III
					if `origprank' > hicut {
					while `k_hi' == . {
						*noi di _n(1) "running `statistic' idgroup = `idgroup', event = `event', k = `k'"
						* search for cutoffs by shifting treated estimate by k
						* and then recalculate treated percentile rank
						replace search = `statistic' - `k' if placebo == 0
						egen `statistic'newrank = rank(search)
						gen `statistic'newprank = `statistic'newrank/(statecount + 1)
						qui sum `statistic'newprank if placebo == 0, d
						local newprank : di %05.4f r(mean)

						* if above above cutoff, stop and complete
						if `newprank' <= hicut local k_hi = `k'
						* otherwise subtract increment and proceed
						if `newprank' > hicut local k = `k' + `increment'

						drop `statistic'newrank `statistic'newprank
						di "k_lo = `k_lo'"
						di "k_hi = `k_hi'"
						di "newprank = `newprank'"
						di "locut = " locut	
						di "hicut = " hicut
						di "origprank = `origprank'"
					}
					while `k_lo' == . {
						*noi di _n(1) "running `statistic' idgroup = `idgroup', event = `event', k = `k'"
						* search for cutoffs by shifting treated estimate by k
						* and then recalculate treated percentile rank
						replace search = `statistic' - `k' if placebo == 0
						egen `statistic'newrank = rank(search)
						gen `statistic'newprank = `statistic'newrank/(statecount + 1)
						qui sum `statistic'newprank if placebo == 0, d
						local newprank : di %05.4f r(mean)

						* if above low cutoff, stop and move onto k_hi
						if `newprank' < locut local k_lo = `k'
						* otherwise subtract increment and proceed
						if `newprank' >= locut local k = `k' + `increment'

						drop `statistic'newrank `statistic'newprank
						di "k_lo = `k_lo'"
						di "k_hi = `k_hi'"
						di "newprank = `newprank'"
						di "locut = " locut	
						di "hicut = " hicut
						di "origprank = `origprank'"
					}
					} // end case III
			
				} // if statecount > 20

				clear
				set obs 1	
				gen `statistic' = `orig'
				gen `statistic'prank = `origprank'
				gen `statistic'loci`cilev' = min(`k_lo',`k_hi')
				gen `statistic'hici`cilev' = max(`k_lo',`k_hi')
				gen byte event = `event'
				gen byte idgroup = `idgroup'
				tempfile `statistic'event`event'idgroup`idgroup'
				save ``statistic'event`event'idgroup`idgroup''
				restore
			} // event

			local counter = 0 
			foreach event of numlist `eventlevels' {
				local counter = `counter' + 1
				if `counter' == 1 use ``statistic'event`event'idgroup`idgroup'', clear
				else append using ``statistic'event`event'idgroup`idgroup''
			} // event
			tempfile `statistic'eventsidgroup`idgroup'
			save ``statistic'eventsidgroup`idgroup''
		} // idgroup
	} // end individual event stats
	
	if "`outputaggregate'" ~= "" {
		* CALCULATE AGGREGATE STAT CIs
		foreach aggstat in `aggstatlist' {
			if "`aggstat'" == "mean" local sumstat mean
			* currently code only makes sense for the mean
			assert "`aggstat'" == "mean"
			forvalues idgroup = 1 / `idgroupmax' {
				use if idgroup == `idgroup' using `basedata', clear
				rename numtrevents numevents
				merge m:1 numevents using `aggcutoffs', keep(3) nogenerate
				if `cilev' == 90 {	
					gen locut = cut5
					gen hicut = cut95
				}
				if `cilev' == 95 {	
					gen locut = cut2_5
					gen hicut = cut97_5
				}
				if "`hodgeslehmann'" ~= "" {
					replace locut = 0.5
					replace hicut = 0.5
				}

				sum `statistic' if placebo == 0, d
				local orig = r(`sumstat')
				sum `statistic'prank if placebo == 0, d
				local origprank = r(`sumstat')

				* generate search variable
				gen search = `statistic'

				local k_lo = .
				local k_hi = .
				local k = 0

				* three cases
				* CASE I: original percentile rank is below low cutoff
				if `origprank' < locut {
				while `k_lo' == . {
					*noi di _n(1) "running `statistic' idgroup = `idgroup', k = `k'"
					* search for cutoffs by shifting treated estimate by k
					* and then recalculate treated percentile rank
					replace search = `statistic' - `k' if placebo == 0
					egen `statistic'newrank = rank(search), by(event)
					gen `statistic'newprank = `statistic'newrank/(statecount + 1)
					sum `statistic'newprank if placebo == 0, d
					local newprank : di %05.4f r(`sumstat')

					* if above low cutoff, stop and move onto k_hi
					if `newprank' >= locut local k_lo = `k'
					* otherwise subtract increment and proceed
					if `newprank' < locut local k = `k' - `increment'

					drop `statistic'newrank `statistic'newprank
					di "k_lo = `k_lo'"
					di "k_hi = `k_hi'"
					di "newprank = `newprank'"
					di "locut = " locut	
					di "hicut = " hicut
					di "origprank = `origprank'"
				}
				while `k_hi' == . {
					*noi di _n(1) "running `statistic' idgroup = `idgroup', k = `k'"
					* search for cutoffs by shifting treated estimate by k
					* and then recalculate treated percentile rank
					replace search = `statistic' - `k' if placebo == 0
					egen `statistic'newrank = rank(search), by(event)
					gen `statistic'newprank = `statistic'newrank/(statecount + 1)
					sum `statistic'newprank if placebo == 0, d
					local newprank : di %05.4f r(`sumstat')

					* if above above cutoff, stop and complete
					if `newprank' > hicut local k_hi = `k'
					* otherwise subtract increment and proceed
					if `newprank' <= hicut local k = `k' - `increment'

					drop `statistic'newrank `statistic'newprank
					di "k_lo = `k_lo'"
					di "k_hi = `k_hi'"
					di "newprank = `newprank'"
					di "locut = " locut	
					di "hicut = " hicut
					di "origprank = `origprank'"
				}
				} // end case I
			
				* CASE II
				if `origprank' >= locut & `origprank' <= hicut {
				while `k_lo' == . {
					*noi di _n(1) "running `statistic' idgroup = `idgroup', k = `k'"
					* search for cutoffs by shifting treated estimate by k
					* and then recalculate treated percentile rank
					replace search = `statistic' - `k' if placebo == 0
					egen `statistic'newrank = rank(search), by(event)
					gen `statistic'newprank = `statistic'newrank/(statecount + 1)
					sum `statistic'newprank if placebo == 0, d
					local newprank : di %05.4f r(`sumstat')

					* if above low cutoff, stop and move onto k_hi
					if `newprank' < locut local k_lo = `k'
					* otherwise subtract increment and proceed
					if `newprank' >= locut local k = `k' + `increment'

					drop `statistic'newrank `statistic'newprank
					di "k_lo = `k_lo'"
					di "k_hi = `k_hi'"
					di "newprank = `newprank'"
					di "locut = " locut	
					di "hicut = " hicut
					di "origprank = `origprank'"
				}
				* reset k = 0
				local k = 0
				while `k_hi' == . {
					*noi di _n(1) "running `statistic' idgroup = `idgroup', k = `k'"
					* search for cutoffs by shifting treated estimate by k
					* and then recalculate treated percentile rank
					replace search = `statistic' - `k' if placebo == 0
					egen `statistic'newrank = rank(search), by(event)
					gen `statistic'newprank = `statistic'newrank/(statecount + 1)
					sum `statistic'newprank if placebo == 0, d
					local newprank : di %05.4f r(`sumstat')

					* if above above cutoff, stop and complete
					if `newprank' > hicut local k_hi = `k'
					* otherwise subtract increment and proceed
					if `newprank' <= hicut local k = `k' - `increment'

					drop `statistic'newrank `statistic'newprank
					di "k_lo = `k_lo'"
					di "k_hi = `k_hi'"
					di "newprank = `newprank'"
					di "locut = " locut	
					di "hicut = " hicut
					di "origprank = `origprank'"
				}
				} // end case II

				* CASE III
				if `origprank' > hicut {
				while `k_hi' == . {
					*noi di _n(1) "running `statistic' idgroup = `idgroup', k = `k'"
					* search for cutoffs by shifting treated estimate by k
					* and then recalculate treated percentile rank
					replace search = `statistic' - `k' if placebo == 0
					egen `statistic'newrank = rank(search), by(event)
					gen `statistic'newprank = `statistic'newrank/(statecount + 1)
					sum `statistic'newprank if placebo == 0, d
					local newprank : di %05.4f r(`sumstat')

					* if above above cutoff, stop and complete
					if `newprank' <= hicut local k_hi = `k'
					* otherwise subtract increment and proceed
					if `newprank' > hicut local k = `k' + `increment'

					drop `statistic'newrank `statistic'newprank
					di "k_lo = `k_lo'"
					di "k_hi = `k_hi'"
					di "newprank = `newprank'"
					di "locut = " locut	
					di "hicut = " hicut
					di "origprank = `origprank'"
				}
				while `k_lo' == . {
					*noi di _n(1) "running `statistic' idgroup = `idgroup', k = `k'"
					* search for cutoffs by shifting treated estimate by k
					* and then recalculate treated percentile rank
					replace search = `statistic' - `k' if placebo == 0
					egen `statistic'newrank = rank(search), by(event)
					gen `statistic'newprank = `statistic'newrank/(statecount + 1)
					sum `statistic'newprank if placebo == 0, d
					local newprank : di %05.4f r(`sumstat')

					* if above low cutoff, stop and move onto k_hi
					if `newprank' < locut local k_lo = `k'
					* otherwise subtract increment and proceed
					if `newprank' >= locut local k = `k' + `increment'

					drop `statistic'newrank `statistic'newprank
					di "k_lo = `k_lo'"
					di "k_hi = `k_hi'"
					di "newprank = `newprank'"
					di "locut = " locut	
					di "hicut = " hicut
					di "origprank = `origprank'"
				}
				} // end case III

				clear
				set obs 1	
				gen `statistic'`aggstat' = `orig'
				gen `statistic'prank`aggstat' = `origprank'
				gen `statistic'`aggstat'loci`cilev' = min(`k_lo',`k_hi')
				gen `statistic'`aggstat'hici`cilev' = max(`k_lo',`k_hi')
				gen byte id = 1
				gen byte idgroup = `idgroup'
				tempfile `statistic'`aggstat'idgroup`idgroup'
				save ``statistic'`aggstat'idgroup`idgroup''
			} // idgroup
		} // aggstat
	}
} // statistic

* merge all the statistic/aggstat datasets
* first, for each pre/post, merge all the stats
qui forvalues idgroup = 1 / `idgroupmax' {

	if "`outputevent'" ~= "" {
		local counter = 0
		foreach statistic in `statlist' {
			local counter = `counter' + 1
			if `counter' == 1 use ``statistic'eventsidgroup`idgroup'', clear
			else merge 1:1 event using ``statistic'eventsidgroup`idgroup'', nogenerate assert(3) 
		} // statistic
	
		tempfile eventsidgroup`idgroup'
		save `eventsidgroup`idgroup''
	}

	if "`outputaggregate'" ~= "" {
		local counter = 0
		foreach statistic in `statlist' {
			foreach aggstat in `aggstatlist' {
				local counter = `counter' + 1
				if `counter' == 1 use ``statistic'`aggstat'idgroup`idgroup'', clear
				else merge 1:1 id using ``statistic'`aggstat'idgroup`idgroup'', nogenerate assert(3) 
			} // aggstat
		} // statistic
		drop id
		tempfile idgroup`idgroup'
		save `idgroup`idgroup''
	}
} // idgroup

* now append all the pre post configs
if "`outputevent'" ~= "" {
	local counter = 0
	forvalues idgroup = 1 / `idgroupmax' {
		local counter = `counter' + 1
		if `counter' == 1 use `eventsidgroup`idgroup'', clear
		else append using `eventsidgroup`idgroup''
	} // idgroup
	merge m:1 idgroup using `idgroupconcordance', nogenerate assert(3)
	drop idgroup
	save `outputevent'
}

if "`outputaggregate'" ~= "" {
	local counter = 0
	forvalues idgroup = 1 / `idgroupmax' {
		local counter = `counter' + 1
		if `counter' == 1 use `idgroup`idgroup'', clear
		else append using `idgroup`idgroup''
	} // idgroup
	merge m:1 idgroup using `idgroupconcordance', nogenerate assert(3)
	drop idgroup
	save `outputaggregate'
}

end






