clear all
set more off
set trace off
prog drop _all
mac drop _all
set matsize 11000

* additional Stata packages from SSC and STB:
* ssc install labutil
* ssc install spell
* ssc install tsspell
* ssc install graphexportpdf
* ssc install moreobs
* ssc install synth
* net stb-29
* net install sg47

* if you want to run create_baseresults, you will also need R and its multicore library 
* see the README for details


******************
*** SET MACROS ***
******************
* set macros. always run this.
global home "/home/benzipperer/projects/dz2015_synthetic_replication/"
global do "${home}do/"
do ${do}set_globalmacros.do



*****************
*** PREP DATA ***
*****************
* create state abbreviations, geography, etc.
do ${do}clean_state_geocodes.do

* create monthly min wage data from Allegretto's data
do ${do}clean_mwdata.do

* clean CPS Basic & MORG - requires Unicon basic monthly and NBER MORG data
*do ${do}clean_cps.do

* create minwage treatment data: stacked panels
do ${do}create_mwtreatmentdata.do

* create synth-ready stacked state-level panels
do ${do}create_macropanel.do



*********************************
*** CREATE SYNTHETIC CONTROLS ***
*********************************
* create synthetic controls for every treatment and donor
* this takes time to run
*do ${do}create_baseresults.do



*************************
*** AGGREGATE RESULTS ***
*************************
* compile all the individual base results into convenient datasets
do ${do}compile_baseresults.do

* aggregate results, predictor matrices, weights
do ${do}aggregate_baseresults.do
do ${do}aggregate_resultsmatrices.do
do ${do}aggregate_vmatrices.do
do ${do}aggregate_weights.do



***********************
*** ANALYZE RESULTS ***
***********************
* create simulated significance data
do ${do}create_simulatedsigdata.do

*invert rank statistic and form CIs
do ${do}invert_ranktest.do

* determine preferred model based on post-rmspe of donors
do ${do}select_preferredmodel.do

* create aggregated results for pre-mspe trimmed donors
do ${do}examine_donormatchquality.do

* create aggregated results by minimal window length
do ${do}examine_windowlength.do

* NEED TO RUN AGAIN with proper iteration #
* calculate CIs using randomization inference on the mean elasticity
do ${do}examine_randominf.do

* NEED TO RUN AGAIN with proper iteration #
* if table 10 looks correct, remove last do-file from nonmwplacebo_master.do 
* using simulated data, examine how treatment overlap affects rejection rates
do ${do}examine_rank_dependence.do



*******************************
*** CREATE FIGURES & TABLES ***
*******************************
* create figures
do ${do}create_figures.do

* create tables
do ${do}create_tables.do






