set more off
global home "/users/benzipperer/projects/dz2015_synthetic_replication/"
global do "${home}do/"
* grab global macros
do ${do}set_globalmacros.do

* grab the macros passed (e.g.,`1',`2',etc.) and convert
* to human readable macros (e.g.,sample,pre,etc.)
local numberofoptions = 0
foreach i in `0' {
	local numberofoptions = `numberofoptions' + 1
}
forvalues i = 1/`numberofoptions' {
	local macroname: di regexr("``i''","=(.)*","")
	local `macroname' : di regexr("``i''","[^=]*=","")
	di "`macroname' = ``macroname''"
}

capture log close
capture log using ${indresults}logs/`procedure'`outcome'_group`group'_pre99_post99${allopt}_iteration`iteration'.log, text replace
macro li

use ${indresults}pre99_post99.dta, clear
* grab all donors and treated for the treatment event used in this iteration
sum treatmentid if iteration == `iteration'
local event = r(mean)
keep if treatmentid == `event'

preserve
qui keep if treated == 1
keep date mwtreatment
tempfile mwtreatmentinfo_iteration`iteration'
save `mwtreatmentinfo_iteration`iteration''
restore

* note that this iteration could be a placebo or actual treatment
* here we determine this and adjust the data accordingly
* if this iteration is a placebo, drop actually treated state
qui sum control if iteration == `iteration'
local placebo = r(mean)
if `placebo' == 1 drop if treated == 1

* create synth parameters
* this will be the treatment info for this iteration
qui sum statefipsnum if iteration == `iteration'
local trunit = r(mean)
qui sum date if post == 1
local trperiod = r(min)

tab statefipsnum if iteration ~= `iteration', nofreq
local numberofdonors = r(r)

tsset statefipsnum date

* control variables
fvexpand ind_*
local industryvars = r(varlist)
local dlmvars whiterate_group`group' blackrate_group`group' femrate_group`group' poprate_group`group' married_group`group' urate college

qui sum date if post == 0
local prebegdate = r(min)
local preenddate = r(max)

local deplist_q ""
local deplist_ann ""
local deplist_all_ann ""


forvalues datevalue = `prebegdate'/`preenddate' {
	local deplist_q `deplist_q' `outcome'_group`group'(`datevalue')
}

* create list of subsequent four-quarter lag averages, for all outcomes
forvalues datevalue = `prebegdate'(4)`preenddate' {
	local enddatevalue = `datevalue' + 3
	local deplist_ann `deplist_ann' `outcome'_group`group'(`datevalue'(3)`enddatevalue')
}

* create list of subsequent four-quarter lag averages, for all outcomes
forvalues datevalue = `prebegdate'(4)`preenddate' {
	local enddatevalue = `datevalue' + 3
	local deplist_all_ann `deplist_all_ann' erate_group`group'(`datevalue'(3)`enddatevalue') wage_group`group'(`datevalue'(3)`enddatevalue')
}



local deplist ""

if regexm("`procedure'", "synth1") == 1 {
	local deplist `deplist_q'
	local indeplist ""
}
if regexm("`procedure'", "synth3") == 1 {
	local deplist `deplist_all_ann'
	local indeplist "`dlmvars' `industryvars'"
}
if regexm("`procedure'", "synth5") == 1 {
	local deplist `deplist_ann'
	local indeplist ""
}
if regexm("`procedure'", "synth6") == 1 {
	local deplist `deplist_all_ann'
	local indeplist ""
}






tempfile synthresults
local uphillerror = 0
local hessianerror = 0


* RUN SYNTHETIC CONTROL PROCEDURE
capture noisily synth `outcome'_group`group' `deplist' `indeplist', trunit(`trunit') trperiod(`trperiod') ${allopt_options}
di "synth RC = " _rc
* if uphill or Hessian failure in allopt optimization, run without allopt
* we will log these for inspection later
if (_rc == 430 | _rc == 504) & "${allopt}" == "_allopt" {
	if _rc == 430 local uphillerror = 1
	if _rc == 504 local hessianerror = 1
	capture noisily synth `outcome'_group`group' `deplist' `indeplist', trunit(`trunit') trperiod(`trperiod')
}


if _rc == 0 {
	mat RMSPE = e(RMSPE)
	local rmspe = RMSPE[1,1]

	preserve
	* grab all y_t, y_s results from all actual and placebo runs
	* merge to mw treatment info for convenience later
	mat y = (e(Y_synthetic),e(Y_treated))
	mat colnames y = y_synthetic y_treated
	clear
	svmat2 y, rnames(date) names(col)

	destring date, replace
	gen byte statefipsnum = `trunit'
	gen rmspe = `rmspe'
	gen byte group = `group'
	gen int event = `event'
	gen byte post = date >= `trperiod'
	gen byte placebo = `placebo'
	gen byte treated = placebo == 0
	assert placebo + treated == 1
	merge m:1 date using `mwtreatmentinfo_iteration`iteration'', assert(3) nogenerate
	save ${indresults}`procedure'`outcome'results_group`group'_pre99_post99${allopt}_iteration`iteration'.dta, replace

	* grab donor weights 
	mat weights = [e(W_weights),J(`numberofdonors',1,`rmspe'),J(`numberofdonors',1,`group'),J(`numberofdonors',1,`event')]
	mat colnames weights = statefipsnum weights rmspe group event
	clear
	svmat weights, names(col)
	gen byte placebo = `placebo'
	gen byte treated = placebo == 0
	save ${indresults}`procedure'`outcome'weights_group`group'_pre99_post99${allopt}_iteration`iteration'.dta, replace

	* grab V matrix
	mat V = vecdiag(e(V_matrix))
	mat vmatrix = V'
	mat colnames vmatrix = weight
	clear
	svmat2 vmatrix, names(col) rnames(predictor)
	gen byte group = `group'
	gen int event = `event'
	gen int statefipsnum = `trunit'
	gen byte placebo = `placebo'
	gen byte treated = placebo == 0
	save ${indresults}`procedure'`outcome'vmatrix_group`group'_pre99_post99${allopt}_iteration`iteration'.dta, replace
	restore

	* log any optimization errors
	if `uphillerror' == 1 | `hessianerror' == 1 {
		clear
		set obs 1
		gen byte group = `group'
		gen int event = `event'
		gen int statefipsnum = `trunit'
		gen byte placebo = `placebo'
		gen byte treated = placebo == 0
		if `uphillerror' == 1 gen error_uphill = 1
		if `hessianerror' == 1 gen error_hessian = 1
		save ${indresults}`procedure'`outcome'error_group`group'_pre99_post99${allopt}_iteration`iteration'.dta, replace
	}

} // _rc == 0

capture log close








