* RUN SINGLE TREATMENT PROCEDURES FOR ALL STATES (ACTUAL AND PLACEBOS)
* iterating over procedures, treatment events, and demo groups
* eventually save results as dta

capture log close 
capture log using ${do}create_nonmwplaceboresults.log, text replace
di "start time = " "$S_TIME"
capture log close

use ${cleandata}finaltreatmentsandcontrols_prelength99_postlength99.dta, clear
keep if treated == 1
egen _treatdate = min(date) if post == 1, by(treatmentid)
egen treatdate = max(_treatdate), by(treatmentid)
keep date treatdate prewindow postwindow 
duplicates drop date treatdate prewindow postwindow, force
egen eventid = group(treatdate prewindow postwindow)
gen post = date >= treatdate
tempfile treatments
save `treatments'

use ${cleandata}cpsbasic_statelevel.dta, clear
merge 1:1 statefipsnum date using ${cleandata}cpsmorg_statelevel.dta, assert(3) nogenerate
merge m:1 statefipsnum using ${cleandata}state_names.dta, assert(3) nogenerate keepusing(statefipsnum stateabb)
drop if stateabb == "DC"
* Stack panels to correspond to treatments
joinby date using `treatments'
egen iteration = group(eventid statefipsnum)

* these data will be used by nonmwplaceboresults_batchjob.do
save ${indresults}nonmwplacebos_pre99_post99.dta, replace


use ${indresults}nonmwplacebos_pre99_post99.dta, clear
foreach procedure in $procedurelist {
	foreach outcome in $outcomelist {
		foreach group of numlist $demogroupnumlist {

		* grab the values over which R will iterate
		qui sum iteration
		local itmin = r(min)
		local itmax = r(max)

		* write R script, which will use snowfall to call instances of stata
		* iterating over iteration numbers
		write_r_script_nonmwplacebos, procedure(`procedure') itbegin(`itmin') itend(`itmax') group(`group') outcome(`outcome') cpus($cpus)

		* run the R script, which calls stata-mp -b results_batchjob.do `options'
		cd ${do}
		* this will now iterate over all iterations using snowfall
		shell R CMD BATCH multicore_R_nonmwplaceboresults.R /dev/null

		} // group
	} // outcome
} // procedure 
	

capture log close 
capture log using ${do}create_nonmwplaceboresults.log, text append
di "end time = " "$S_TIME"
capture log close


