set more off
global home "/home/benzipperer/projects/dz2015_synthetic_replication/nonmwplacebo/"
global do "${home}do/"
* grab global macros
do ${do}set_nonmwplacebo_globalmacros.do

* grab the macros passed (e.g.,`1',`2',etc.) and convert
* to human readable macros (e.g.,sample,pre,etc.)
local numberofoptions = 0
foreach i in `0' {
	local numberofoptions = `numberofoptions' + 1
}
forvalues i = 1/`numberofoptions' {
	local macroname: di regexr("``i''","=(.)*","")
	local `macroname' : di regexr("``i''","[^=]*=","")
	di "`macroname' = ``macroname''"
}



capture log close
capture log using ${indresults}logs/`procedure'`outcome'_group`group'${allopt}_nonmwplaceboiteration`iteration'.log, text replace
macro li

use ${indresults}nonmwplacebos_pre99_post99.dta, clear

* recall that the iteration variable in this data signifies the exact stateXtreatmentid
sum treatdate if iteration == `iteration'
local trperiod = r(mean)
qui sum statefipsnum if iteration == `iteration'
local trunit = r(mean)
local placebo = 1
tab statefipsnum if statefipsnum ~= `trunit', nofreq
local numberofdonors = r(r)

* restrict the data to the appropriate panel
sum eventid if iteration == `iteration'
assert r(min) == r(max)
keep if eventid == r(mean)
sum prewindow
local prewindow = r(mean)
sum postwindow
local postwindow = r(mean)

tsset statefipsnum date

* control variables
fvexpand ind_*
local industryvars = r(varlist)
local dlmvars whiterate_group`group' blackrate_group`group' femrate_group`group' poprate_group`group' married_group`group' urate college

qui sum date if post == 0
local prebegdate = r(min)
local preenddate = r(max)

local deplist_q ""
local deplist_ann ""
local deplist_all_ann ""


forvalues datevalue = `prebegdate'/`preenddate' {
	local deplist_q `deplist_q' `outcome'_group`group'(`datevalue')
}

* create list of subsequent four-quarter lag averages, for all outcomes
forvalues datevalue = `prebegdate'(4)`preenddate' {
	local enddatevalue = `datevalue' + 3
	local deplist_ann `deplist_ann' `outcome'_group`group'(`datevalue'(3)`enddatevalue')
}

* create list of subsequent four-quarter lag averages, for all outcomes
forvalues datevalue = `prebegdate'(4)`preenddate' {
	local enddatevalue = `datevalue' + 3
	local deplist_all_ann `deplist_all_ann' erate_group`group'(`datevalue'(3)`enddatevalue') wage_group`group'(`datevalue'(3)`enddatevalue')
}

local deplist ""

if regexm("`procedure'", "synth1") == 1 {
	local center = 0
	local deplist `deplist_q'
	local indeplist ""
}
if regexm("`procedure'", "synth2") == 1 {
	local center = 0
	local deplist `deplist_ann'
	local indeplist "`dlmvars' `industryvars'"
}
if regexm("`procedure'", "synth3") == 1 {
	local center = 0
	local deplist `deplist_all_ann'
	local indeplist "`dlmvars' `industryvars'"
}
if regexm("`procedure'", "synth4") == 1 {
	local center = 1
	local deplist `deplist_q'
	local indeplist ""
}


* if running a "centered" specification, 
* center both outcome variables around pre-treatment mean
if `center' == 1 {
	foreach outcomevar in erate wage {
		egen _premean = mean(`outcomevar'_group`group') if post == 0, by(statefipsnum)
		egen premean = max(_premean), by(statefipsnum)
		replace `outcomevar'_group`group' = `outcomevar'_group`group' - premean
		sum premean if statefipsnum == `trunit'
		local premean_`outcomevar' = r(mean) 
		drop premean _premean
	}
}


tempfile synthresults
local uphillerror = 0
local hessianerror = 0


capture noisily synth `outcome'_group`group' `deplist' `indeplist', trunit(`trunit') trperiod(`trperiod') ${allopt_options}
* if uphill failure in allopt optimization, run without allopt
di "synth RC = " _rc
* if uphill or Hessian failure in allopt optimization, run without allopt
if (_rc == 430 | _rc == 504) & "${allopt}" == "_allopt" {
	if _rc == 430 local uphillerror = 1
	if _rc == 504 local hessianerror = 1
	capture noisily synth `outcome'_group`group' `deplist' `indeplist', trunit(`trunit') trperiod(`trperiod')
}

if _rc == 0 {
mat RMSPE = e(RMSPE)
local rmspe = RMSPE[1,1]

preserve
* grab all y_t, y_s results from all actual and placebo runs
mat y = (e(Y_synthetic),e(Y_treated))
mat colnames y = y_synthetic y_treated
clear
svmat2 y, rnames(date) names(col)
destring date, replace
format date %tq
gen statefipsnum = `trunit'
gen rmspe = `rmspe'
gen group = `group'
gen iteration = `iteration'
gen post = date >= `trperiod'
gen prewindow = `prewindow'
gen postwindow = `postwindow'
gen treatdate = `trperiod'
format %tq treatdate
gen placebo = `placebo'
gen treated = placebo == 0
assert placebo + treated == 1
compress
save ${indresults}`procedure'`outcome'results_group`group'_pre99_post99${allopt}_nonmwplaceboiteration`iteration'.dta, replace

* grab donor weights 
mat weights = [e(W_weights),J(`numberofdonors',1,`rmspe'),J(`numberofdonors',1,`group'),J(`numberofdonors',1,`iteration')]
mat colnames weights = statefipsnum weights rmspe group iteration
clear
svmat weights, names(col)
gen placebo = `placebo'
gen treated = placebo == 0
compress
save ${indresults}`procedure'`outcome'weights_group`group'_pre99_post99${allopt}_nonmwplaceboiteration`iteration'.dta, replace

* grab V matrix
mat V = vecdiag(e(V_matrix))
mat vmatrix = V'
mat colnames vmatrix = weight
clear
svmat2 vmatrix, names(col) rnames(predictor)
gen group = `group'
gen iteration = `iteration'
gen statefipsnum = `trunit'
gen placebo = `placebo'
gen treated = placebo == 0
compress
save ${indresults}`procedure'`outcome'vmatrix_group`group'_pre99_post99${allopt}_nonmwplaceboiteration`iteration'.dta, replace
restore

if `uphillerror' == 1 {
clear
set obs 1
gen group = `group'
gen iteration = `iteration'
gen statefipsnum = `trunit'
gen placebo = `placebo'
gen treated = placebo == 0
gen error_uphill = 1
compress
save ${indresults}`procedure'`outcome'error_group`group'_pre99_post99${allopt}_nonmwplaceboiteration`iteration'.dta, replace
}

} // _rc == 0

capture log close








